// The Exchange: Genetically Evolving Market Agents 
// Written by David J. Stein, Esq., 11/22/2004. See "License.html" for terms and conditions of use.
//
// This module contains the code for the Agent Arena form, including the genetic training algorithm.

#region Using declarations

using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Threading;
using System.Windows.Forms;
using System.Web.Mail;

#endregion

namespace The_Exchange_Namespace {

	public class ExchangeAgentArena : System.Windows.Forms.Form	{
		// This class represents the Agent Arena dialog.

		#region Variables and initialization code

		// genetic algorithm variables
		private int iPopulationSize = 100;
		private double dMutationRate = 0.1;
		private double dNewEntities = 0.1;
		private double dKeptParents = 0.1;
		private double dBuddingRate = 0.05;
		// other variables
		public ArrayList agents;
		public ExchangeSimulation exchange;
		bool bContinue = false;
		int iLastClick = 0;
		private Random random;
		public Thread thread;
		public int iNumGames = 100;

		// window controls
		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.GroupBox groupBox2;
		private System.ComponentModel.Container components = null;
		private System.Windows.Forms.ListView lstAgents;
		private System.Windows.Forms.ListView lstRankings;
		private System.Windows.Forms.Button btnRunOnce;
		private System.Windows.Forms.Button btnSave;
		private System.Windows.Forms.Button btnLoad;
		private System.Windows.Forms.TextBox txtStatus;
		private System.Windows.Forms.ColumnHeader columnHeader1;
		private System.Windows.Forms.ColumnHeader columnHeader3;
		private System.Windows.Forms.ColumnHeader columnHeader4;
		private System.Windows.Forms.ColumnHeader columnHeader5;
		private System.Timers.Timer timerStatus;
		private System.Windows.Forms.ColumnHeader columnHeader2;
		private System.Windows.Forms.Button btnDeleteAgent;
		private System.Windows.Forms.Button btnSaveSet;
		private System.Windows.Forms.Button btnLoadSet;
		private System.Windows.Forms.Button btnClearSet;
		private System.Windows.Forms.GroupBox groupBox3;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.Label label5;
		private System.Windows.Forms.NumericUpDown nudImmigration;
		private System.Windows.Forms.NumericUpDown nudBudding;
		private System.Windows.Forms.NumericUpDown nudMutation;
		private System.Windows.Forms.NumericUpDown nudKeptParents;
		private System.Windows.Forms.NumericUpDown nudPopulationSize;
		private System.Windows.Forms.ColumnHeader columnHeader6;
		private System.Windows.Forms.ColumnHeader columnHeader7;
		private System.Windows.Forms.Button btnTrain;
		private System.Windows.Forms.Button btnViewAgent;
		private System.Windows.Forms.Button btnAddAgent;
		private System.Windows.Forms.Label label6;
		private System.Windows.Forms.NumericUpDown nudGamesPerPhase;
		private System.Windows.Forms.Label label7;
		private System.Windows.Forms.TextBox txtEmailAddress;
		private System.Windows.Forms.GroupBox groupBox4;
		private System.Windows.Forms.NumericUpDown nudNotifyFrequency;
		private System.Windows.Forms.Label label8;
		private System.Windows.Forms.Label label9;
		private System.Windows.Forms.Label label10;
		private System.Windows.Forms.TextBox txtSMTPServer;
		private System.Windows.Forms.TextBox txtMessageSource;
		private System.Windows.Forms.Label label11;
		private System.Windows.Forms.TextBox txtStartGeneration;
		private System.Windows.Forms.ColumnHeader columnHeader8;

		public ExchangeAgentArena()	{
			InitializeComponent();
			exchange = null;
			thread = null;
			agents = new ArrayList();
			random = new Random((int) System.DateTime.Now.Ticks);
			for (int i = 0; i < iPopulationSize; i++)
				agents.Add(new ExchangeAgent_Programmed(random));
			UpdateAgentList();
		}

		#endregion

		#region Genetic algorithm functions

		private void RunSimulation(bool bDisplay, ArrayList players) {
			// This function runs a full simulation.
			exchange = new ExchangeSimulation(random);
			foreach (ExchangeAgent agent in players)
				exchange.AddAgent(agent);
			while (exchange.bDone == false) {
				exchange.Step();
				if ((bDisplay == true) && (exchange.iTimer == 0))
					txtStatus.Text = exchange.Time();
			}
		}

		private void RunOnce() {
			// This function causes the simulation to run once and displays results.
			RunSimulation(true, agents);
			// done - output player rankings
			lstRankings.BeginUpdate();
			lstRankings.Items.Clear();
			foreach (ExchangeAgent agent in exchange.agents) {
				lstRankings.Items.Add(new ListViewItem(new string[] { agent.player.strName, agent.player.lTotalValue.ToString(), agent.player.iRank.ToString()} ) );
			}
			lstRankings.EndUpdate();
			lstRankings.Refresh();
			btnRunOnce.Enabled = true;
			btnRunOnce.Refresh();
			Thread abortThread = thread;
			thread = null;
			abortThread.Abort();
		}

		private void Train() {
			// This function causes the simulation to run continuously over the population set.
			// The function sends monitoring output to a local file.
			DateTime tLastUpdate = DateTime.Now;
			System.IO.StreamWriter s = new System.IO.StreamWriter(@"C:\trainlog.txt", true);
			s.WriteLine("=====");
			s.WriteLine("Exchange Agent Arena - starting at " + System.DateTime.Now.ToLongDateString() + " " + System.DateTime.Now.ToLongTimeString());
			int iCount = 0;
			if (txtStartGeneration.Text.Length > 0) {
				try { iCount = Int32.Parse(txtStartGeneration.Text) - 1; } catch {}
			}
			bContinue = true;
			double lRecordMaxValue = 0;
			// check agent list - pad up to population limit if not enough agents
			while (agents.Count < iPopulationSize)
				agents.Add(new ExchangeAgent_Programmed(random));
			while (bContinue == true) {
				iCount++;
				foreach (ExchangeAgent agent in agents) {  // zero all counts
					agent.dFitness = 0.0;
					agent.dRank = 0.0;
					agent.lValue = 0;
				}
				// run games
				for (int repeat = 1; repeat <= iNumGames; repeat++) {   // run the appropriate number of games (with 10 agents in each game)
					BitArray played = new BitArray(iPopulationSize, false);
					for (int i = 0; i < iPopulationSize; i += 10) {
						ArrayList players = new ArrayList();
						for (int j = 0; j < 10; j++) {
							int nextPlayer = random.Next(iPopulationSize);
							while (played[nextPlayer] == true)
								nextPlayer = random.Next(iPopulationSize);
							played[nextPlayer] = true;
							players.Add(agents[nextPlayer]);
						}
						RunSimulation(false, players);
					}
					if (repeat % 10 == 0)
						txtStatus.Text = "Generation " + iCount + ": Games " + repeat;
				}
				// evaluate
				long lAverageValue = 0;
				foreach (ExchangeAgent agent in agents)
					lAverageValue += agent.lValue;
				lAverageValue = lAverageValue / agents.Count / iNumGames;
				txtStatus.Text = "Creating generation " + (iCount + 1) + " - value: " + lAverageValue;
				CalculateAgentFitnesses();
				UpdateAgentList();
				// write results
				s.WriteLine("Generation " + iCount + " (" + System.DateTime.Now.ToShortTimeString() + "): average value = " + lAverageValue);
				bool bNewMax = false;
				for (int i = 0; i < 5; i++) {
					s.WriteLine(" " + ((ExchangeAgent_Programmed) agents[i]).dFitness.ToString("#.###") + " (" + ((ExchangeAgent_Programmed) agents[i]).lValue.ToString() + ", " + ((ExchangeAgent_Programmed) agents[i]).dRank.ToString("#.###") + ", Games: " + ((ExchangeAgent_Programmed) agents[i]).iGames.ToString()  + ")");
					if (((ExchangeAgent_Programmed) agents[i]).lValue > lRecordMaxValue) {
						bNewMax = true;
						s.WriteLine("   * New high max value - writing " + ((ExchangeAgent_Programmed) agents[i]).strName + " to file.");
						((ExchangeAgent_Programmed) agents[i]).Save(@"C:\Agents\" + ((ExchangeAgent_Programmed) agents[i]).strName + ".exa");
						lRecordMaxValue = ((ExchangeAgent_Programmed) agents[i]).lValue;
					}
				}
				if ((bNewMax) || ((iCount % (int) nudNotifyFrequency.Value == 0) && (txtEmailAddress.Text.Length > 0))) {  // send notification email
					MailMessage message = new MailMessage();
					message.To = txtEmailAddress.Text;
					if (txtMessageSource.Text.Length > 0)
						message.From = txtMessageSource.Text;
					else if (txtEmailAddress.Text.IndexOf("@") != -1)
						message.From = "ExchangeArena" + txtEmailAddress.Text.Substring(txtEmailAddress.Text.IndexOf("@"));
					else
						message.From = txtEmailAddress.Text;
					message.Subject = "Exchange Agent Arena Notification: Phase " + iCount + ", Value = " + lAverageValue + (bNewMax == true ? " (New Max)" : "");
					message.BodyEncoding = System.Text.Encoding.ASCII;
					message.Body = "Exchange Agent Arena Notification (Phase " + iCount + ")";
					message.Body += System.Environment.NewLine;
					message.Body += System.Environment.NewLine;
					message.Body += "================================================";
					message.Body += System.Environment.NewLine;
					message.Body += System.Environment.NewLine;
					message.Body += "Average Value: " + lAverageValue;
					message.Body += System.Environment.NewLine;
					message.Body += "Top agents:";
					message.Body += System.Environment.NewLine;
					for (int i = 0; i < iPopulationSize / 10; i++) {
						message.Body += " " + ((ExchangeAgent_Programmed) agents[i]).strName + " - Fitness: " + ((ExchangeAgent_Programmed) agents[i]).dFitness.ToString("#.###") + " (Average Value: " + ((int) (((ExchangeAgent_Programmed) agents[i]).lValue / iNumGames)).ToString() + ", Average Rank: " + ((float) ((ExchangeAgent_Programmed) agents[i]).dRank / iNumGames).ToString("#.###") + ", Games: " + ((ExchangeAgent_Programmed) agents[i]).iGames.ToString() + ")";
						message.Body += System.Environment.NewLine;
						message.Body += System.Environment.NewLine;
					}
					System.Web.Mail.SmtpMail.SmtpServer = txtSMTPServer.Text;
					try {
						System.Web.Mail.SmtpMail.Send(message);
					} catch {}
				}
				// update time and save agent set if we hit an hour mark
				if (DateTime.Now.Hour != tLastUpdate.Hour)
					ExchangeAgent_Programmed.SaveSet(@"C:\Agents\Agent Set " + DateTime.Now.ToString("yyyyMMddHH") + ".exs", agents);
				ProduceAgentSet(random);
			}
			s.WriteLine("Exchange Agent Arena - Ending at " + System.DateTime.Now.ToLongDateString() + " " + System.DateTime.Now.ToLongTimeString());
			s.WriteLine("=====");
			s.WriteLine("");
			s.Close();
			UpdateAgentList();
			btnTrain.Text = "Train";
			btnTrain.Refresh();
			Thread abortThread = thread;
			thread = null;
			abortThread.Abort();
		}

		public void CalculateAgentFitnesses() {
			// compute total fitnesses
			double lMaxValue = 0;
			double dMaxRank = 0.0;
			foreach (ExchangeAgent agent in agents) {
				lMaxValue = Math.Max(lMaxValue, agent.lValue);
				dMaxRank = Math.Max(dMaxRank, agent.dRank);
			}
			foreach (ExchangeAgent agent in agents)
				agent.dFitness = (1.0 - (agent.dRank / dMaxRank / (double) 3.0)) + ((double) agent.lValue / (double) lMaxValue * (double) 2.0 / (double) 3.0);
			// sort agent set
			ArrayList lstSortedAgents = new ArrayList();
			while (agents.Count > 0) {
				ExchangeAgent topAgent = (ExchangeAgent) agents[0];
				for (int i = 1; i < agents.Count; i++) {
					if (((ExchangeAgent) agents[i]).dFitness > topAgent.dFitness)
						topAgent = (ExchangeAgent) agents[i];
				}
				agents.Remove(topAgent);
				lstSortedAgents.Add(topAgent);
			}
			agents = lstSortedAgents;
		}

		public void ProduceAgentSet(Random r) {
			// This function produces a new agent set based on the genetic fitness of each agent.
			ArrayList lstNewAgents = new ArrayList();

			// calculate total fitness
			double totalFitness = 0.0;
			foreach (ExchangeAgent agent in agents)
				totalFitness += agent.dFitness;

			// calculate composition of next generation
			int iKeptParents = (int) ((dKeptParents) * iPopulationSize);
			int iBudding = (int) ((dBuddingRate) * iPopulationSize);
			int iNewEntities = (int) ((dNewEntities) * iPopulationSize);
			int iMutations = (int) ((dMutationRate) * iPopulationSize);
			int iCrossover = iPopulationSize - iKeptParents - iBudding - iNewEntities;

			// keep top parents (copy into temporary array)
			ArrayList lstKeptParents = new ArrayList();
			if (dKeptParents > 0.0) {
				foreach (ExchangeAgent_Programmed agent in agents) {
					if (lstKeptParents.Count == 0)
						lstKeptParents.Add(agent);
					else {
						bool added = false;
						for (int i = 0; i < Math.Min(lstKeptParents.Count, iKeptParents); i++) {
							if (((ExchangeAgent_Programmed) lstKeptParents[i]).dFitness < agent.dFitness) {
								lstKeptParents.Insert(i, agent);
								added = true;
								break;
							}
						}
						if ((added == false) && (lstKeptParents.Count < iKeptParents))
							lstKeptParents.Add(agent);
						while (lstKeptParents.Count > iKeptParents)
							lstKeptParents.RemoveAt(iKeptParents);
					}
				}
			}

			// budding
			while (lstNewAgents.Count < iBudding) {
				// budding
				double dParent = random.NextDouble() * totalFitness;
				ExchangeAgent_Programmed agentParent = null;
				for (int i = 0; i < iPopulationSize; i++) {
					ExchangeAgent_Programmed agent = (ExchangeAgent_Programmed) agents[i];
					if (dParent <= agent.dFitness) {
						agentParent = agent;
						break;
					}
					else
						dParent -= agent.dFitness;
				}
				if (agentParent != null) {
					ExchangeAgent_Programmed agentChild = null;
					agentChild = new ExchangeAgent_Programmed(random);
					int iBreakStart = random.Next(ExchangeAgent_Programmed.iProgramSize);
					int iBreakEnd = random.Next(ExchangeAgent_Programmed.iProgramSize);
					while (iBreakEnd == iBreakStart)
						iBreakEnd = random.Next(ExchangeAgent_Programmed.iProgramSize);
					if (iBreakEnd > iBreakStart) {
						for (int j = iBreakStart; j < iBreakEnd; j++)
							agentChild.cProgram[j] = agentParent.cProgram[j];
					}
					else {
						for (int j = iBreakStart; j < ExchangeAgent_Programmed.iProgramSize; j++)
							agentChild.cProgram[j] = agentParent.cProgram[j];
						for (int j = 0; j < iBreakStart; j++)
							agentChild.cProgram[j] = agentParent.cProgram[j];
					}
					lstNewAgents.Add(agentChild);
				}
			}

			// crossover children
			while (lstNewAgents.Count < iBudding + iCrossover) {
				double dFather = random.NextDouble() * totalFitness;
				double dMother = random.NextDouble() * totalFitness;
				ExchangeAgent_Programmed agentFather = null, agentMother = null;
				for (int i = 0; i < iPopulationSize; i++) {
					ExchangeAgent_Programmed agent = (ExchangeAgent_Programmed) agents[i];
					if (dFather >= 0.0) {
						if (dFather <= agent.dFitness) {
							agentFather = agent;
							dFather = -1;  // stop looking
							if (dMother == -1)
								break;
						}
						else
							dFather -= agent.dFitness;
					}
					if (dMother >= 0.0) {
						if (dMother <= agent.dFitness) {
							agentMother = agent;
							dMother = -1;  // stop looking
							if (dFather == -1)
								break;
						}
						else
							dMother -= agent.dFitness;
					}
				}
				if ((agentMother != null) && (agentFather != null)) {
					ExchangeAgent_Programmed agentChild = null;
					agentChild = new ExchangeAgent_Programmed(random);
					int iBreakStart = random.Next(ExchangeAgent_Programmed.iProgramSize);
					int iBreakEnd = random.Next(ExchangeAgent_Programmed.iProgramSize);
					while (iBreakEnd == iBreakStart)
						iBreakEnd = random.Next(ExchangeAgent_Programmed.iProgramSize);
					if (iBreakEnd > iBreakStart) {
						for (int j = iBreakStart; j < iBreakEnd; j++)
							agentChild.cProgram[j] = agentMother.cProgram[j];
						for (int j = 0; j < iBreakStart; j++)
							agentChild.cProgram[j] = agentFather.cProgram[j];
						for (int j = iBreakEnd; j < ExchangeAgent_Programmed.iProgramSize; j++)
							agentChild.cProgram[j] = agentFather.cProgram[j];
					}
					else {
						for (int j = iBreakEnd; j < iBreakStart; j++)
							agentChild.cProgram[j] = agentFather.cProgram[j];
						for (int j = iBreakStart; j < ExchangeAgent_Programmed.iProgramSize; j++)
							agentChild.cProgram[j] = agentMother.cProgram[j];
						for (int j = 0; j < iBreakStart; j++)
							agentChild.cProgram[j] = agentMother.cProgram[j];
					}
					lstNewAgents.Add(agentChild);
				}
			}

			// immigration
			while (lstNewAgents.Count < iBudding + iCrossover + iNewEntities)
				lstNewAgents.Add(new ExchangeAgent_Programmed(random));

			// mutations
			for (int i = 0; i < iMutations; i++) {
				ExchangeAgent_Programmed agentMutated = new ExchangeAgent_Programmed(random);
				// select one of the new entities and copy program to new agent
				ExchangeAgent_Programmed agentOriginal = (ExchangeAgent_Programmed) lstNewAgents[random.Next(lstNewAgents.Count)];
				for (int j = 0; j < ExchangeAgent_Programmed.iProgramSize; j++)
					agentMutated.cProgram[j] = agentOriginal.cProgram[j];
				agentMutated.cProgram[random.Next(ExchangeAgent_Programmed.iProgramSize)] = (char) random.Next(256);  // randomly mutate one character
				lstNewAgents.Remove(agentOriginal);
				lstNewAgents.Add(agentMutated);
			}

			// add in kept parents
			for (int i = lstKeptParents.Count - 1; i >= 0; i--)
				lstNewAgents.Insert(0, lstKeptParents[i]);

			// set child entities list to master list and exit
			agents = lstNewAgents;

		}

		#endregion

		#region User interface event handlers 

		private void lstAgents_Click(object sender, System.EventArgs e) {
			// This function handles double-clicking on an agent in the agent list to view it.
			int iTimeNow = 60000 * System.DateTime.Now.Minute + 1000 * System.DateTime.Now.Second + System.DateTime.Now.Millisecond;
			if ((iTimeNow > iLastClick) && (iTimeNow < iLastClick + 600) && (lstAgents.SelectedIndices.Count == 1)) {
				ExchangeAgentDisplayDialog display = new ExchangeAgentDisplayDialog((ExchangeAgent) agents[lstAgents.SelectedIndices[0]], iNumGames);
				display.ShowDialog();
			}
			else
				iLastClick = iTimeNow;
		}

		private void btnCreate_Click(object sender, System.EventArgs e) {
			// This function handles clicking of the Create button.
			agents.Add(new ExchangeAgent_Programmed(random));
			UpdateAgentList();
		}

		private void btnRemove_Click(object sender, System.EventArgs e) {
			// This function handles clicking of the Remove button.
			if (lstAgents.SelectedIndices.Count == 1) {
				agents.RemoveAt(lstAgents.SelectedIndices[0]);
				UpdateAgentList();
			}
		}

		private void btnRunOnce_Click(object sender, System.EventArgs e) {
			// This function handles clicking of the RunOnce button.
			thread = new Thread(new ThreadStart(RunOnce));
			thread.Start();
			btnRunOnce.Enabled = false;
			btnRunOnce.Refresh();
		}

		private void btnTrain_Click(object sender, System.EventArgs e) {
			// This function handles clicking of the Train button.
			if (thread == null) {
				thread = new Thread(new ThreadStart(Train));
				thread.Start();
				btnTrain.Text = "Stop";
				btnTrain.Refresh();
			}
			else {  // thread is already running - signal it to stop
				btnTrain.Text = "Stopping";
				btnTrain.Refresh();
				bContinue = false;  // this will trigger program to stop running
			}
		}

		private void btnSave_Click(object sender, System.EventArgs e) {
			// This function handles clicking of the Save Agent button.
			if (lstAgents.SelectedItems.Count == 1) {
				SaveFileDialog s = new SaveFileDialog();
				s.Filter = "Exchange Agents (*.exa)|*.exa";
				s.OverwritePrompt = true;
				if (s.ShowDialog() == DialogResult.OK)
					((ExchangeAgent_Programmed) agents[lstAgents.SelectedIndices[0]]).Save(s.FileName);
			}
		}

		private void btnLoad_Click(object sender, System.EventArgs e) {
			// This function handles clicking of the Load Agent button.
			OpenFileDialog open = new OpenFileDialog();
			open.Filter = "Exchange Agents (*.exa)|*.exa";
			if (open.ShowDialog() == DialogResult.OK) {  // selected an XML file
				ExchangeAgent agent = ExchangeAgent_Programmed.Load(open.FileName);
				if (agent != null) {
					agents.Add(agent);
					UpdateAgentList();
				}
			}
		}

		private void btnDeleteAgent_Click(object sender, System.EventArgs e) {
			// This function handles clicking of the Delete Agent button.
			if (lstAgents.SelectedItems.Count == 1) {
				agents.RemoveAt(lstAgents.SelectedIndices[0]);
				UpdateAgentList();
			}
		}

		private void btnSaveSet_Click(object sender, System.EventArgs e) {
			// This function handles clicking of the Save Set button.
			SaveFileDialog s = new SaveFileDialog();
			s.Filter = "Exchange Agent Sets (*.exs)|*.exs";
			s.OverwritePrompt = true;
			if (s.ShowDialog() == DialogResult.OK)
				ExchangeAgent_Programmed.SaveSet(s.FileName, agents);
		}

		private void btnLoadSet_Click(object sender, System.EventArgs e) {
			// This function handles clicking of the Load Set button.
			OpenFileDialog open = new OpenFileDialog();
			open.Filter = "Exchange Agent Set (*.exs)|*.exs";
			if (open.ShowDialog() == DialogResult.OK) {  // selected an XML file
				ArrayList newagentset = ExchangeAgent_Programmed.LoadSet(open.FileName);
				if (newagentset != null) {
					agents = newagentset;
					UpdateAgentList();
				}
			}
		}

		private void btnClearSet_Click(object sender, System.EventArgs e) {
			// This function handles clicking of the Clear Set button.
			agents = new ArrayList();
			for (int i = 0; i < iPopulationSize; i++)
				agents.Add(new ExchangeAgent_Programmed(random));
			UpdateAgentList();
		}

		private void btnAddAgent_Click(object sender, System.EventArgs e) {
			// This function adds a random agent to the agent list.
			agents.Add(new ExchangeAgent_Programmed(random));
			UpdateAgentList();
		}

		private void btnViewAgent_Click(object sender, System.EventArgs e) {
			// This function displays the dialog box for viewing  the selected agent.
			if (lstAgents.SelectedIndices.Count > 0) {
				ExchangeAgentDisplayDialog d = new ExchangeAgentDisplayDialog((ExchangeAgent) agents[lstAgents.SelectedIndices[0]], iNumGames);
				d.Show();
			}
		}

		private void nudPopulationSize_ValueChanged(object sender, System.EventArgs e) {
			// This function handles changes to the Population Size numeric-up/down box.
			if (nudPopulationSize.Value % 10 == 0)  // must be a multiple of 10.
				iPopulationSize = (int) nudPopulationSize.Value;
		}

		private void nudKeptParents_ValueChanged(object sender, System.EventArgs e) {
			// This function handles changes to the Kept Parents numeric-up/down box.
			if (dBuddingRate + dNewEntities + (((double) nudKeptParents.Value) / 100.0f) > 1.0) {
				nudKeptParents.Value = (int) (dKeptParents * 100);
				nudKeptParents.Refresh();
			}
			else
				dKeptParents = (double) ((double) nudKeptParents.Value / 100.0);
		}

		private void nudBudding_ValueChanged(object sender, System.EventArgs e) {
			// This function handles changes to the Budding numeric-up/down box.
			if (dKeptParents + dNewEntities + (((double) nudBudding.Value) / 100.0f) > 1.0) {
				nudBudding.Value = (int) (dBuddingRate * 100);
				nudBudding.Refresh();
			}
			else
				dBuddingRate = (double) ((double) nudBudding.Value / 100.0);
		}

		private void nudImmigration_ValueChanged(object sender, System.EventArgs e) {
			// This function handles changes to the Immigration numeric-up/down box.
			if (dBuddingRate + dKeptParents + (((double) nudImmigration.Value) / 100.0f) > 1.0) {
				nudImmigration.Value = (int) (dNewEntities * 100);
				nudImmigration.Refresh();
			}
			else
				dNewEntities = (double) ((double) nudImmigration.Value / 100.0);
		}

		private void nudGamesPerPhase_ValueChanged(object sender, System.EventArgs e) {
			iNumGames = (int) nudGamesPerPhase.Value;
		}

		#endregion

		#region Other event handlers

		private void timerStatus_Elapsed(object sender, System.Timers.ElapsedEventArgs e) {
			// This button handles timer tick functions (refresh the txtStatus field once per second.)
			if (thread != null)
				txtStatus.Refresh();
		}

		private void ExchangeAgentArena_Closing(object sender, System.ComponentModel.CancelEventArgs e) {
			// This function handles closing of the dialog - ensures that the training thread isn't left running in the background after the form is closed.
			if (thread != null) {
				thread.Abort();
				thread = null;
			}
		}
		#endregion

		#region Helper functions

		public void UpdateAgentList() {
			// This function updates the list of current agents.
			lstAgents.BeginUpdate();
			lstAgents.Items.Clear();
			for (int i = 0; i < agents.Count; i++) {
				ExchangeAgent agent = (ExchangeAgent) agents[i];
				lstAgents.Items.Add(new ListViewItem(new string[] { agent.strName, agent.iGames.ToString(), agent.dFitness.ToString("#.##"), ((float) (agent.dRank / (float) iNumGames)).ToString("#.##"), ((long) (agent.lValue / iNumGames)).ToString()  } ) );
			}
			lstAgents.EndUpdate();
			lstAgents.Refresh();
		}

		#endregion

		#region Uninteresting Windows Form Designer generated code

		protected override void Dispose(bool disposing)		{
			if (disposing) {
				if (components != null) {
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		private void InitializeComponent()	{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(ExchangeAgentArena));
			this.lstAgents = new System.Windows.Forms.ListView();
			this.columnHeader1 = new System.Windows.Forms.ColumnHeader();
			this.columnHeader6 = new System.Windows.Forms.ColumnHeader();
			this.columnHeader8 = new System.Windows.Forms.ColumnHeader();
			this.columnHeader3 = new System.Windows.Forms.ColumnHeader();
			this.columnHeader7 = new System.Windows.Forms.ColumnHeader();
			this.lstRankings = new System.Windows.Forms.ListView();
			this.columnHeader4 = new System.Windows.Forms.ColumnHeader();
			this.columnHeader5 = new System.Windows.Forms.ColumnHeader();
			this.columnHeader2 = new System.Windows.Forms.ColumnHeader();
			this.btnRunOnce = new System.Windows.Forms.Button();
			this.btnSave = new System.Windows.Forms.Button();
			this.btnLoad = new System.Windows.Forms.Button();
			this.txtStatus = new System.Windows.Forms.TextBox();
			this.groupBox1 = new System.Windows.Forms.GroupBox();
			this.btnTrain = new System.Windows.Forms.Button();
			this.groupBox2 = new System.Windows.Forms.GroupBox();
			this.btnViewAgent = new System.Windows.Forms.Button();
			this.btnAddAgent = new System.Windows.Forms.Button();
			this.btnDeleteAgent = new System.Windows.Forms.Button();
			this.btnClearSet = new System.Windows.Forms.Button();
			this.btnSaveSet = new System.Windows.Forms.Button();
			this.btnLoadSet = new System.Windows.Forms.Button();
			this.timerStatus = new System.Timers.Timer();
			this.groupBox3 = new System.Windows.Forms.GroupBox();
			this.nudGamesPerPhase = new System.Windows.Forms.NumericUpDown();
			this.label6 = new System.Windows.Forms.Label();
			this.nudImmigration = new System.Windows.Forms.NumericUpDown();
			this.nudBudding = new System.Windows.Forms.NumericUpDown();
			this.nudKeptParents = new System.Windows.Forms.NumericUpDown();
			this.nudPopulationSize = new System.Windows.Forms.NumericUpDown();
			this.label5 = new System.Windows.Forms.Label();
			this.label4 = new System.Windows.Forms.Label();
			this.label2 = new System.Windows.Forms.Label();
			this.label1 = new System.Windows.Forms.Label();
			this.nudMutation = new System.Windows.Forms.NumericUpDown();
			this.label3 = new System.Windows.Forms.Label();
			this.label7 = new System.Windows.Forms.Label();
			this.txtEmailAddress = new System.Windows.Forms.TextBox();
			this.groupBox4 = new System.Windows.Forms.GroupBox();
			this.label10 = new System.Windows.Forms.Label();
			this.txtSMTPServer = new System.Windows.Forms.TextBox();
			this.label9 = new System.Windows.Forms.Label();
			this.txtMessageSource = new System.Windows.Forms.TextBox();
			this.nudNotifyFrequency = new System.Windows.Forms.NumericUpDown();
			this.label8 = new System.Windows.Forms.Label();
			this.label11 = new System.Windows.Forms.Label();
			this.txtStartGeneration = new System.Windows.Forms.TextBox();
			this.groupBox1.SuspendLayout();
			this.groupBox2.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.timerStatus)).BeginInit();
			this.groupBox3.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.nudGamesPerPhase)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.nudImmigration)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.nudBudding)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.nudKeptParents)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.nudPopulationSize)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.nudMutation)).BeginInit();
			this.groupBox4.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.nudNotifyFrequency)).BeginInit();
			this.SuspendLayout();
			// 
			// lstAgents
			// 
			this.lstAgents.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
				| System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.lstAgents.Columns.AddRange(new System.Windows.Forms.ColumnHeader[] {
																												this.columnHeader1,
																												this.columnHeader6,
																												this.columnHeader8,
																												this.columnHeader3,
																												this.columnHeader7});
			this.lstAgents.FullRowSelect = true;
			this.lstAgents.Location = new System.Drawing.Point(16, 24);
			this.lstAgents.Name = "lstAgents";
			this.lstAgents.Size = new System.Drawing.Size(320, 520);
			this.lstAgents.TabIndex = 0;
			this.lstAgents.View = System.Windows.Forms.View.Details;
			this.lstAgents.Click += new System.EventHandler(this.lstAgents_Click);
			// 
			// columnHeader1
			// 
			this.columnHeader1.Text = "Name";
			this.columnHeader1.Width = 100;
			// 
			// columnHeader6
			// 
			this.columnHeader6.Text = "Games";
			this.columnHeader6.Width = 45;
			// 
			// columnHeader8
			// 
			this.columnHeader8.Text = "Fitness";
			this.columnHeader8.Width = 45;
			// 
			// columnHeader3
			// 
			this.columnHeader3.Text = "Rank";
			this.columnHeader3.Width = 45;
			// 
			// columnHeader7
			// 
			this.columnHeader7.Text = "Value";
			// 
			// lstRankings
			// 
			this.lstRankings.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
				| System.Windows.Forms.AnchorStyles.Left)));
			this.lstRankings.Columns.AddRange(new System.Windows.Forms.ColumnHeader[] {
																												  this.columnHeader4,
																												  this.columnHeader5,
																												  this.columnHeader2});
			this.lstRankings.Location = new System.Drawing.Point(16, 24);
			this.lstRankings.Name = "lstRankings";
			this.lstRankings.Size = new System.Drawing.Size(184, 168);
			this.lstRankings.TabIndex = 0;
			this.lstRankings.View = System.Windows.Forms.View.Details;
			// 
			// columnHeader4
			// 
			this.columnHeader4.Text = "Name";
			// 
			// columnHeader5
			// 
			this.columnHeader5.Text = "Value";
			// 
			// columnHeader2
			// 
			this.columnHeader2.Text = "Rank";
			// 
			// btnRunOnce
			// 
			this.btnRunOnce.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
			this.btnRunOnce.Location = new System.Drawing.Point(16, 240);
			this.btnRunOnce.Name = "btnRunOnce";
			this.btnRunOnce.Size = new System.Drawing.Size(88, 23);
			this.btnRunOnce.TabIndex = 2;
			this.btnRunOnce.Text = "Run Once";
			this.btnRunOnce.Click += new System.EventHandler(this.btnRunOnce_Click);
			// 
			// btnSave
			// 
			this.btnSave.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
			this.btnSave.Location = new System.Drawing.Point(98, 552);
			this.btnSave.Name = "btnSave";
			this.btnSave.Size = new System.Drawing.Size(72, 23);
			this.btnSave.TabIndex = 2;
			this.btnSave.Text = "Save Agent";
			this.btnSave.Click += new System.EventHandler(this.btnSave_Click);
			// 
			// btnLoad
			// 
			this.btnLoad.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
			this.btnLoad.Location = new System.Drawing.Point(98, 584);
			this.btnLoad.Name = "btnLoad";
			this.btnLoad.Size = new System.Drawing.Size(72, 23);
			this.btnLoad.TabIndex = 6;
			this.btnLoad.Text = "Load Agent";
			this.btnLoad.Click += new System.EventHandler(this.btnLoad_Click);
			// 
			// txtStatus
			// 
			this.txtStatus.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
			this.txtStatus.Location = new System.Drawing.Point(16, 208);
			this.txtStatus.Name = "txtStatus";
			this.txtStatus.ReadOnly = true;
			this.txtStatus.Size = new System.Drawing.Size(184, 20);
			this.txtStatus.TabIndex = 1;
			this.txtStatus.Text = "Status: Ready";
			// 
			// groupBox1
			// 
			this.groupBox1.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.groupBox1.Controls.Add(this.btnTrain);
			this.groupBox1.Controls.Add(this.txtStatus);
			this.groupBox1.Controls.Add(this.btnRunOnce);
			this.groupBox1.Controls.Add(this.lstRankings);
			this.groupBox1.Location = new System.Drawing.Point(368, 8);
			this.groupBox1.Name = "groupBox1";
			this.groupBox1.Size = new System.Drawing.Size(216, 272);
			this.groupBox1.TabIndex = 1;
			this.groupBox1.TabStop = false;
			this.groupBox1.Text = "Arena";
			// 
			// btnTrain
			// 
			this.btnTrain.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
			this.btnTrain.Location = new System.Drawing.Point(112, 240);
			this.btnTrain.Name = "btnTrain";
			this.btnTrain.Size = new System.Drawing.Size(88, 23);
			this.btnTrain.TabIndex = 3;
			this.btnTrain.Text = "Train";
			this.btnTrain.Click += new System.EventHandler(this.btnTrain_Click);
			// 
			// groupBox2
			// 
			this.groupBox2.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
				| System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.groupBox2.Controls.Add(this.btnViewAgent);
			this.groupBox2.Controls.Add(this.btnAddAgent);
			this.groupBox2.Controls.Add(this.btnDeleteAgent);
			this.groupBox2.Controls.Add(this.btnClearSet);
			this.groupBox2.Controls.Add(this.btnSaveSet);
			this.groupBox2.Controls.Add(this.btnLoadSet);
			this.groupBox2.Controls.Add(this.btnSave);
			this.groupBox2.Controls.Add(this.lstAgents);
			this.groupBox2.Controls.Add(this.btnLoad);
			this.groupBox2.Location = new System.Drawing.Point(8, 8);
			this.groupBox2.Name = "groupBox2";
			this.groupBox2.Size = new System.Drawing.Size(352, 616);
			this.groupBox2.TabIndex = 0;
			this.groupBox2.TabStop = false;
			this.groupBox2.Text = "Agent List";
			// 
			// btnViewAgent
			// 
			this.btnViewAgent.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
			this.btnViewAgent.Location = new System.Drawing.Point(16, 584);
			this.btnViewAgent.Name = "btnViewAgent";
			this.btnViewAgent.Size = new System.Drawing.Size(72, 23);
			this.btnViewAgent.TabIndex = 5;
			this.btnViewAgent.Text = "View Agent";
			this.btnViewAgent.Click += new System.EventHandler(this.btnViewAgent_Click);
			// 
			// btnAddAgent
			// 
			this.btnAddAgent.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
			this.btnAddAgent.Location = new System.Drawing.Point(16, 552);
			this.btnAddAgent.Name = "btnAddAgent";
			this.btnAddAgent.Size = new System.Drawing.Size(72, 23);
			this.btnAddAgent.TabIndex = 1;
			this.btnAddAgent.Text = "Add Agent";
			this.btnAddAgent.Click += new System.EventHandler(this.btnAddAgent_Click);
			// 
			// btnDeleteAgent
			// 
			this.btnDeleteAgent.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
			this.btnDeleteAgent.Location = new System.Drawing.Point(180, 552);
			this.btnDeleteAgent.Name = "btnDeleteAgent";
			this.btnDeleteAgent.Size = new System.Drawing.Size(72, 23);
			this.btnDeleteAgent.TabIndex = 3;
			this.btnDeleteAgent.Text = "Del Agent";
			this.btnDeleteAgent.Click += new System.EventHandler(this.btnDeleteAgent_Click);
			// 
			// btnClearSet
			// 
			this.btnClearSet.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
			this.btnClearSet.Location = new System.Drawing.Point(180, 584);
			this.btnClearSet.Name = "btnClearSet";
			this.btnClearSet.Size = new System.Drawing.Size(72, 23);
			this.btnClearSet.TabIndex = 7;
			this.btnClearSet.Text = "Clear Set";
			this.btnClearSet.Click += new System.EventHandler(this.btnClearSet_Click);
			// 
			// btnSaveSet
			// 
			this.btnSaveSet.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
			this.btnSaveSet.Location = new System.Drawing.Point(262, 552);
			this.btnSaveSet.Name = "btnSaveSet";
			this.btnSaveSet.Size = new System.Drawing.Size(72, 23);
			this.btnSaveSet.TabIndex = 4;
			this.btnSaveSet.Text = "Save Set";
			this.btnSaveSet.Click += new System.EventHandler(this.btnSaveSet_Click);
			// 
			// btnLoadSet
			// 
			this.btnLoadSet.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
			this.btnLoadSet.Location = new System.Drawing.Point(262, 584);
			this.btnLoadSet.Name = "btnLoadSet";
			this.btnLoadSet.Size = new System.Drawing.Size(72, 23);
			this.btnLoadSet.TabIndex = 8;
			this.btnLoadSet.Text = "Load Set";
			this.btnLoadSet.Click += new System.EventHandler(this.btnLoadSet_Click);
			// 
			// timerStatus
			// 
			this.timerStatus.Enabled = true;
			this.timerStatus.SynchronizingObject = this;
			this.timerStatus.Elapsed += new System.Timers.ElapsedEventHandler(this.timerStatus_Elapsed);
			// 
			// groupBox3
			// 
			this.groupBox3.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
			this.groupBox3.Controls.Add(this.label11);
			this.groupBox3.Controls.Add(this.nudGamesPerPhase);
			this.groupBox3.Controls.Add(this.label6);
			this.groupBox3.Controls.Add(this.nudImmigration);
			this.groupBox3.Controls.Add(this.nudBudding);
			this.groupBox3.Controls.Add(this.nudKeptParents);
			this.groupBox3.Controls.Add(this.nudPopulationSize);
			this.groupBox3.Controls.Add(this.label5);
			this.groupBox3.Controls.Add(this.label4);
			this.groupBox3.Controls.Add(this.label2);
			this.groupBox3.Controls.Add(this.label1);
			this.groupBox3.Controls.Add(this.nudMutation);
			this.groupBox3.Controls.Add(this.label3);
			this.groupBox3.Controls.Add(this.txtStartGeneration);
			this.groupBox3.Location = new System.Drawing.Point(368, 288);
			this.groupBox3.Name = "groupBox3";
			this.groupBox3.Size = new System.Drawing.Size(216, 200);
			this.groupBox3.TabIndex = 2;
			this.groupBox3.TabStop = false;
			this.groupBox3.Text = "Genetic Algorithm Parameters";
			// 
			// nudGamesPerPhase
			// 
			this.nudGamesPerPhase.Location = new System.Drawing.Point(112, 24);
			this.nudGamesPerPhase.Maximum = new System.Decimal(new int[] {
																								 10000,
																								 0,
																								 0,
																								 0});
			this.nudGamesPerPhase.Minimum = new System.Decimal(new int[] {
																								 1,
																								 0,
																								 0,
																								 0});
			this.nudGamesPerPhase.Name = "nudGamesPerPhase";
			this.nudGamesPerPhase.Size = new System.Drawing.Size(96, 20);
			this.nudGamesPerPhase.TabIndex = 0;
			this.nudGamesPerPhase.Value = new System.Decimal(new int[] {
																							  100,
																							  0,
																							  0,
																							  0});
			this.nudGamesPerPhase.ValueChanged += new System.EventHandler(this.nudGamesPerPhase_ValueChanged);
			// 
			// label6
			// 
			this.label6.Location = new System.Drawing.Point(8, 24);
			this.label6.Name = "label6";
			this.label6.Size = new System.Drawing.Size(96, 23);
			this.label6.TabIndex = 5;
			this.label6.Text = "Games Per Phase";
			this.label6.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// nudImmigration
			// 
			this.nudImmigration.Location = new System.Drawing.Point(112, 120);
			this.nudImmigration.Name = "nudImmigration";
			this.nudImmigration.Size = new System.Drawing.Size(96, 20);
			this.nudImmigration.TabIndex = 4;
			this.nudImmigration.Value = new System.Decimal(new int[] {
																							10,
																							0,
																							0,
																							0});
			this.nudImmigration.ValueChanged += new System.EventHandler(this.nudImmigration_ValueChanged);
			// 
			// nudBudding
			// 
			this.nudBudding.Location = new System.Drawing.Point(112, 96);
			this.nudBudding.Name = "nudBudding";
			this.nudBudding.Size = new System.Drawing.Size(96, 20);
			this.nudBudding.TabIndex = 3;
			this.nudBudding.Value = new System.Decimal(new int[] {
																					  10,
																					  0,
																					  0,
																					  0});
			this.nudBudding.ValueChanged += new System.EventHandler(this.nudBudding_ValueChanged);
			// 
			// nudKeptParents
			// 
			this.nudKeptParents.Location = new System.Drawing.Point(112, 72);
			this.nudKeptParents.Name = "nudKeptParents";
			this.nudKeptParents.Size = new System.Drawing.Size(96, 20);
			this.nudKeptParents.TabIndex = 2;
			this.nudKeptParents.Value = new System.Decimal(new int[] {
																							10,
																							0,
																							0,
																							0});
			this.nudKeptParents.ValueChanged += new System.EventHandler(this.nudKeptParents_ValueChanged);
			// 
			// nudPopulationSize
			// 
			this.nudPopulationSize.Location = new System.Drawing.Point(112, 48);
			this.nudPopulationSize.Maximum = new System.Decimal(new int[] {
																								  1000,
																								  0,
																								  0,
																								  0});
			this.nudPopulationSize.Minimum = new System.Decimal(new int[] {
																								  1,
																								  0,
																								  0,
																								  0});
			this.nudPopulationSize.Name = "nudPopulationSize";
			this.nudPopulationSize.Size = new System.Drawing.Size(96, 20);
			this.nudPopulationSize.TabIndex = 1;
			this.nudPopulationSize.Value = new System.Decimal(new int[] {
																								100,
																								0,
																								0,
																								0});
			this.nudPopulationSize.ValueChanged += new System.EventHandler(this.nudPopulationSize_ValueChanged);
			// 
			// label5
			// 
			this.label5.Location = new System.Drawing.Point(8, 120);
			this.label5.Name = "label5";
			this.label5.Size = new System.Drawing.Size(96, 23);
			this.label5.TabIndex = 4;
			this.label5.Text = "Immigration (%)";
			this.label5.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label4
			// 
			this.label4.Location = new System.Drawing.Point(8, 96);
			this.label4.Name = "label4";
			this.label4.Size = new System.Drawing.Size(96, 23);
			this.label4.TabIndex = 3;
			this.label4.Text = "Budding (%)";
			this.label4.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label2
			// 
			this.label2.Location = new System.Drawing.Point(8, 72);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(96, 23);
			this.label2.TabIndex = 1;
			this.label2.Text = "Kept Parents (%)";
			this.label2.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(8, 48);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(96, 23);
			this.label1.TabIndex = 0;
			this.label1.Text = "Population Size";
			this.label1.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// nudMutation
			// 
			this.nudMutation.Location = new System.Drawing.Point(112, 144);
			this.nudMutation.Name = "nudMutation";
			this.nudMutation.Size = new System.Drawing.Size(96, 20);
			this.nudMutation.TabIndex = 5;
			this.nudMutation.Value = new System.Decimal(new int[] {
																						5,
																						0,
																						0,
																						0});
			// 
			// label3
			// 
			this.label3.Location = new System.Drawing.Point(8, 144);
			this.label3.Name = "label3";
			this.label3.Size = new System.Drawing.Size(96, 23);
			this.label3.TabIndex = 2;
			this.label3.Text = "Mutation (%)";
			this.label3.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label7
			// 
			this.label7.Location = new System.Drawing.Point(8, 24);
			this.label7.Name = "label7";
			this.label7.Size = new System.Drawing.Size(96, 23);
			this.label7.TabIndex = 7;
			this.label7.Text = "Email Address";
			this.label7.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// txtEmailAddress
			// 
			this.txtEmailAddress.Location = new System.Drawing.Point(112, 24);
			this.txtEmailAddress.Name = "txtEmailAddress";
			this.txtEmailAddress.Size = new System.Drawing.Size(96, 20);
			this.txtEmailAddress.TabIndex = 0;
			this.txtEmailAddress.Text = "";
			// 
			// groupBox4
			// 
			this.groupBox4.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
			this.groupBox4.Controls.Add(this.label10);
			this.groupBox4.Controls.Add(this.txtSMTPServer);
			this.groupBox4.Controls.Add(this.label9);
			this.groupBox4.Controls.Add(this.txtMessageSource);
			this.groupBox4.Controls.Add(this.label7);
			this.groupBox4.Controls.Add(this.txtEmailAddress);
			this.groupBox4.Controls.Add(this.nudNotifyFrequency);
			this.groupBox4.Controls.Add(this.label8);
			this.groupBox4.Location = new System.Drawing.Point(368, 496);
			this.groupBox4.Name = "groupBox4";
			this.groupBox4.Size = new System.Drawing.Size(216, 128);
			this.groupBox4.TabIndex = 3;
			this.groupBox4.TabStop = false;
			this.groupBox4.Text = "Notification";
			// 
			// label10
			// 
			this.label10.Location = new System.Drawing.Point(8, 72);
			this.label10.Name = "label10";
			this.label10.Size = new System.Drawing.Size(96, 23);
			this.label10.TabIndex = 11;
			this.label10.Text = "SMTP Server";
			this.label10.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// txtSMTPServer
			// 
			this.txtSMTPServer.Location = new System.Drawing.Point(112, 72);
			this.txtSMTPServer.Name = "txtSMTPServer";
			this.txtSMTPServer.Size = new System.Drawing.Size(96, 20);
			this.txtSMTPServer.TabIndex = 2;
			this.txtSMTPServer.Text = "";
			// 
			// label9
			// 
			this.label9.Location = new System.Drawing.Point(8, 48);
			this.label9.Name = "label9";
			this.label9.Size = new System.Drawing.Size(96, 23);
			this.label9.TabIndex = 9;
			this.label9.Text = "Message Source";
			this.label9.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// txtMessageSource
			// 
			this.txtMessageSource.Location = new System.Drawing.Point(112, 48);
			this.txtMessageSource.Name = "txtMessageSource";
			this.txtMessageSource.Size = new System.Drawing.Size(96, 20);
			this.txtMessageSource.TabIndex = 1;
			this.txtMessageSource.Text = "";
			// 
			// nudNotifyFrequency
			// 
			this.nudNotifyFrequency.Location = new System.Drawing.Point(112, 96);
			this.nudNotifyFrequency.Name = "nudNotifyFrequency";
			this.nudNotifyFrequency.Size = new System.Drawing.Size(96, 20);
			this.nudNotifyFrequency.TabIndex = 3;
			this.nudNotifyFrequency.Value = new System.Decimal(new int[] {
																								 10,
																								 0,
																								 0,
																								 0});
			// 
			// label8
			// 
			this.label8.Location = new System.Drawing.Point(8, 96);
			this.label8.Name = "label8";
			this.label8.Size = new System.Drawing.Size(96, 23);
			this.label8.TabIndex = 7;
			this.label8.Text = "Notify Frequency";
			this.label8.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label11
			// 
			this.label11.Location = new System.Drawing.Point(8, 168);
			this.label11.Name = "label11";
			this.label11.Size = new System.Drawing.Size(96, 23);
			this.label11.TabIndex = 6;
			this.label11.Text = "First Generation";
			this.label11.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// txtStartGeneration
			// 
			this.txtStartGeneration.Location = new System.Drawing.Point(112, 168);
			this.txtStartGeneration.Name = "txtStartGeneration";
			this.txtStartGeneration.Size = new System.Drawing.Size(96, 20);
			this.txtStartGeneration.TabIndex = 12;
			this.txtStartGeneration.Text = "0";
			// 
			// ExchangeAgentArena
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(592, 630);
			this.Controls.Add(this.groupBox4);
			this.Controls.Add(this.groupBox3);
			this.Controls.Add(this.groupBox2);
			this.Controls.Add(this.groupBox1);
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.MinimumSize = new System.Drawing.Size(600, 480);
			this.Name = "ExchangeAgentArena";
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
			this.Text = "Exchange Agent Arena";
			this.Closing += new System.ComponentModel.CancelEventHandler(this.ExchangeAgentArena_Closing);
			this.groupBox1.ResumeLayout(false);
			this.groupBox2.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.timerStatus)).EndInit();
			this.groupBox3.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.nudGamesPerPhase)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.nudImmigration)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.nudBudding)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.nudKeptParents)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.nudPopulationSize)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.nudMutation)).EndInit();
			this.groupBox4.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.nudNotifyFrequency)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion

	}
}
