// The Exchange: Genetically Evolving Market Agents 
// Written by David J. Stein, Esq., 11/22/2004. See "License.html" for terms and conditions of use.
//
// This module contains the code for the Exchange simulation game.

#region Using declarations

using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;

#endregion

namespace The_Exchange_Namespace {

	public class ExchangeGame : System.Windows.Forms.Form	{
		// This class represents the dialog for running the Exchange game.

		#region Variables and initialization code

		public ExchangeSimulation exchange;
		private System.Windows.Forms.Button btnGood1Buy;
		private System.Windows.Forms.Button btnGood1Sell;
		private System.Windows.Forms.Button btnGood2Sell;
		private System.Windows.Forms.Button btnGood2Buy;
		private System.Windows.Forms.Button btnGood3Sell;
		private System.Windows.Forms.Button btnGood3Buy;
		private System.Windows.Forms.Button btnGood4Sell;
		private System.Windows.Forms.Button btnGood4Buy;
		private System.Windows.Forms.Button btnGood5Sell;
		private System.Windows.Forms.Button btnGood5Buy;
		private System.Windows.Forms.Button btnGood6Sell;
		private System.Windows.Forms.Button btnGood6Buy;
		private System.Windows.Forms.Button btnGood7Sell;
		private System.Windows.Forms.Button btnGood7Buy;
		private System.Windows.Forms.Button btnGood8Sell;
		private System.Windows.Forms.Button btnGood8Buy;
		private System.Windows.Forms.Button btnGood9Sell;
		private System.Windows.Forms.Button btnGood9Buy;
		private System.Windows.Forms.TextBox txtStatus;
		private System.Windows.Forms.Label label13;
		private System.Windows.Forms.Button btnStartStop;
		private System.ComponentModel.IContainer components;
		private System.Windows.Forms.RadioButton rbProduceGood1;
		private System.Windows.Forms.RadioButton rbProduceGood2;
		private System.Windows.Forms.RadioButton rbProduceGood3;
		private System.Windows.Forms.RadioButton rbProduceGood5;
		private System.Windows.Forms.RadioButton rbProduceGood4;
		private System.Windows.Forms.RadioButton rbProduceGood6;
		private System.Windows.Forms.RadioButton rbProduceGood9;
		private System.Windows.Forms.RadioButton rbProduceGood8;
		private System.Windows.Forms.RadioButton rbProduceGood7;
		private System.Windows.Forms.TextBox txtTime;
		private System.Windows.Forms.ListView lstScoreboard;
		private System.Windows.Forms.ColumnHeader headerName;
		private System.Windows.Forms.ColumnHeader headerValue;
		private System.Windows.Forms.Button btnGood6Buy10;
		private System.Windows.Forms.Button btnGood7Buy10;
		private System.Windows.Forms.Button btnGood8Buy10;
		private System.Windows.Forms.Button btnGood9Buy10;
		private System.Windows.Forms.Button btnGood5Buy10;
		private System.Windows.Forms.Button btnGood4Buy10;
		private System.Windows.Forms.Button btnGood3Buy10;
		private System.Windows.Forms.Button btnGood2Buy10;
		private System.Windows.Forms.Button btnGood1Buy10;
		private System.Windows.Forms.Button btnGood6Sell10;
		private System.Windows.Forms.Button btnGood7Sell10;
		private System.Windows.Forms.Button btnGood8Sell10;
		private System.Windows.Forms.Button btnGood9Sell10;
		private System.Windows.Forms.Button btnGood5Sell10;
		private System.Windows.Forms.Button btnGood4Sell10;
		private System.Windows.Forms.Button btnGood3Sell10;
		private System.Windows.Forms.Button btnGood2Sell10;
		private System.Windows.Forms.Button btnGood1Sell10;
		private System.Windows.Forms.Timer timerMarket;
		private System.Windows.Forms.Timer timerTicker;
		private System.Windows.Forms.ColumnHeader headerProduction;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.GroupBox grpControls;
		private System.Windows.Forms.GroupBox grpRankings;
		private System.Windows.Forms.ColumnHeader headerRank;
		private System.Windows.Forms.PictureBox picMarket;
		private System.Windows.Forms.Label label56;
		private System.Windows.Forms.Label lblGood1;
		private System.Windows.Forms.Label lblGood2;
		private System.Windows.Forms.Label lblGood3;
		private System.Windows.Forms.Label lblGood4;
		private System.Windows.Forms.Label lblGood5;
		private System.Windows.Forms.Label lblGood6;
		private System.Windows.Forms.Label lblGood7;
		private System.Windows.Forms.Label lblGood8;
		private System.Windows.Forms.Label lblGood9;
		private System.Windows.Forms.Label lblCredits;

		public ExchangeGame() {
			InitializeComponent();
			exchange = new ExchangeSimulation(new Random((int) System.DateTime.Now.Ticks));
			exchange.bDone = true;
			// set labels
			lblGood1.Text = ((Good) exchange.goods[0]).strName;
			lblGood2.Text = ((Good) exchange.goods[1]).strName;
			lblGood3.Text = ((Good) exchange.goods[2]).strName;
			lblGood4.Text = ((Good) exchange.goods[3]).strName;
			lblGood5.Text = ((Good) exchange.goods[4]).strName;
			lblGood6.Text = ((Good) exchange.goods[5]).strName;
			lblGood7.Text = ((Good) exchange.goods[6]).strName;
			lblGood8.Text = ((Good) exchange.goods[7]).strName;
			lblGood9.Text = ((Good) exchange.goods[8]).strName;
		}

		#endregion

		#region User interface event handlers

		private void btnStartStop_Click(object sender, System.EventArgs e) {
			// This function starts a new game, and pauses or resumes the current game.
			if (exchange.bRunning == true) {
				timerMarket.Stop();
				exchange.bRunning = false;
				txtStatus.Text += " * Paused * ";
				txtStatus.Refresh();
				btnStartStop.Text = "Resume";
				btnStartStop.Refresh();
			}
			else {
				if (exchange.bDone == true) {  // start new game
					ExchangeNewGameDialog newgame = new ExchangeNewGameDialog();
					if (newgame.ShowDialog(this) == DialogResult.OK) {
						txtStatus.Text += " * Beginning Game * ";
						exchange = new ExchangeSimulation(new Random((int) System.DateTime.Now.Ticks));
						exchange.AddAgent(new ExchangeAgent_Console(newgame.consolename));
						foreach (ExchangeAgent agent in newgame.agents)
							exchange.AddAgent(agent);
						rbProduceGood1.Checked = true;
						rbProduceGood2.Checked = false;
						rbProduceGood3.Checked = false;
						rbProduceGood4.Checked = false;
						rbProduceGood5.Checked = false;
						rbProduceGood6.Checked = false;
						rbProduceGood7.Checked = false;
						rbProduceGood8.Checked = false;
						rbProduceGood9.Checked = false;
						txtStatus.Refresh();
						timerMarket.Start();
						exchange.bRunning = true;
						txtStatus.Refresh();
						btnStartStop.Text = "Pause";
						btnStartStop.Refresh();
						UpdateNumbers();
					}
				}
				else {
					txtStatus.Text += " * Resuming * ";
					txtStatus.Refresh();
					timerMarket.Start();
					exchange.bRunning = true;
					txtStatus.Refresh();
					btnStartStop.Text = "Pause";
					btnStartStop.Refresh();
					UpdateNumbers();
				}
			}
		}

		private void btnGoodBuy_Click(object sender, System.EventArgs e) {
			// This function handles the console player clicks of the "Buy" buttons.
			if (sender == btnGood1Buy)
				exchange.Buy(0, 0, 1);
			else if (sender == btnGood2Buy)
				exchange.Buy(0, 1, 1);
			else if (sender == btnGood3Buy)
				exchange.Buy(0, 2, 1);
			else if (sender == btnGood4Buy)
				exchange.Buy(0, 3, 1);
			else if (sender == btnGood5Buy)
				exchange.Buy(0, 4, 1);
			else if (sender == btnGood6Buy)
				exchange.Buy(0, 5, 1);
			else if (sender == btnGood7Buy)
				exchange.Buy(0, 6, 1);
			else if (sender == btnGood8Buy)
				exchange.Buy(0, 7, 1);
			else if (sender == btnGood9Buy)
				exchange.Buy(0, 8, 1);
			else if (sender == btnGood1Buy10)
				exchange.Buy(0, 0, 10);
			else if (sender == btnGood2Buy10)
				exchange.Buy(0, 1, 10);
			else if (sender == btnGood3Buy10)
				exchange.Buy(0, 2, 10);
			else if (sender == btnGood4Buy10)
				exchange.Buy(0, 3, 10);
			else if (sender == btnGood5Buy10)
				exchange.Buy(0, 4, 10);
			else if (sender == btnGood6Buy10)
				exchange.Buy(0, 5, 10);
			else if (sender == btnGood7Buy10)
				exchange.Buy(0, 6, 10);
			else if (sender == btnGood8Buy10)
				exchange.Buy(0, 7, 10);
			else if (sender == btnGood9Buy10)
				exchange.Buy(0, 8, 10);
			UpdateNumbers();
		}

		private void btnGoodSell_Click(object sender, System.EventArgs e) {
			// This function handles the console player clicks of the "Sell" buttons.
			if (sender == btnGood1Sell)
				exchange.Sell(0, 0, 1);
			else if (sender == btnGood2Sell)
				exchange.Sell(0, 1, 1);
			else if (sender == btnGood3Sell)
				exchange.Sell(0, 2, 1);
			else if (sender == btnGood4Sell)
				exchange.Sell(0, 3, 1);
			else if (sender == btnGood5Sell)
				exchange.Sell(0, 4, 1);
			else if (sender == btnGood6Sell)
				exchange.Sell(0, 5, 1);
			else if (sender == btnGood7Sell)
				exchange.Sell(0, 6, 1);
			else if (sender == btnGood8Sell)
				exchange.Sell(0, 7, 1);
			else if (sender == btnGood9Sell)
				exchange.Sell(0, 8, 1);
			else if (sender == btnGood1Sell10)
				exchange.Sell(0, 0, 10);
			else if (sender == btnGood2Sell10)
				exchange.Sell(0, 1, 10);
			else if (sender == btnGood3Sell10)
				exchange.Sell(0, 2, 10);
			else if (sender == btnGood4Sell10)
				exchange.Sell(0, 3, 10);
			else if (sender == btnGood5Sell10)
				exchange.Sell(0, 4, 10);
			else if (sender == btnGood6Sell10)
				exchange.Sell(0, 5, 10);
			else if (sender == btnGood7Sell10)
				exchange.Sell(0, 6, 10);
			else if (sender == btnGood8Sell10)
				exchange.Sell(0, 7, 10);
			else if (sender == btnGood9Sell10)
				exchange.Sell(0, 8, 10);
			UpdateNumbers();
		}

		private void rbProduceGood_CheckedChanged(object sender, System.EventArgs e) {
			// This function handles console player clicks of the Production radio buttons.
			if (rbProduceGood1.Checked)
				((ExchangeAgent) exchange.agents[0]).iProduction = 0;
			else if ( rbProduceGood2.Checked)
				((ExchangeAgent) exchange.agents[0]).iProduction = 1;
			else if ( rbProduceGood3.Checked)
				((ExchangeAgent) exchange.agents[0]).iProduction = 2;
			else if ( rbProduceGood4.Checked)
				((ExchangeAgent) exchange.agents[0]).iProduction = 3;
			else if ( rbProduceGood5.Checked)
				((ExchangeAgent) exchange.agents[0]).iProduction = 4;
			else if ( rbProduceGood6.Checked)
				((ExchangeAgent) exchange.agents[0]).iProduction = 5;
			else if ( rbProduceGood7.Checked)
				((ExchangeAgent) exchange.agents[0]).iProduction = 6;
			else if ( rbProduceGood8.Checked)
				((ExchangeAgent) exchange.agents[0]).iProduction = 7;
			else if ( rbProduceGood9.Checked)
				((ExchangeAgent) exchange.agents[0]).iProduction = 8;
		}

		private void lstScoreboard_Click(object sender, System.EventArgs e) {
			// This function displays a dialog box showing the stats of the clicked player.
			if (lstScoreboard.SelectedIndices.Count > 0) {
				for (int i = 0; i < exchange.agents.Count; i++) {
					if (((ExchangeAgent) exchange.agents[i]).player.iRank == lstScoreboard.SelectedIndices[0] + 1) {
						ExchangePlayerDialog p = new ExchangePlayerDialog((ExchangeAgent) exchange.agents[i], exchange);
						p.Show();
					}
				}
			}
		}
		#endregion

		#region Other event handlers

		private void timerMarket_Tick(object sender, System.EventArgs e) {
			// This function handles the market ticker. It executes an update of the market simulation, updates the current display, and stops the timer if the game has ended.
			exchange.Step();
			UpdateNumbers();
			if (exchange.bRunning == false) {  // game over, man
				timerMarket.Stop();
				txtStatus.Text += " * GAME OVER * ";
				txtStatus.Refresh();
				txtTime.Text = "0:0:0";
				txtTime.Refresh();
				btnStartStop.Text = "New Game";
				btnStartStop.Refresh();
			}
		}

		private void timerTicker_Tick(object sender, System.EventArgs e) {
			// This function handles the news ticker. It moves the message across the ticker box.
			txtStatus.Text = txtStatus.Text.Substring(1) + exchange.strNews + (txtStatus.Text.Length < 69 ? "-" : "");
			exchange.strNews = "";
			txtStatus.Refresh();
			picMarket.Refresh();
		}

		private void picMarket_Paint(object sender, System.Windows.Forms.PaintEventArgs e) {
			// This function handles repainting the market display chart (graphs and bar charts.)
			Font font = new Font("Times New Roman", 7.5f);
			Font font2 = new Font("Times New Roman", 9.0f);
			StringFormat format = new StringFormat();
			format.Alignment = StringAlignment.Center;
			Graphics g = e.Graphics;
			g.SmoothingMode = System.Drawing.Drawing2D.SmoothingMode.AntiAlias;
			g.FillRectangle(new SolidBrush(Color.FromArgb(0, 0, 0)), e.ClipRectangle);
			Color[] color = new Color[9];
			color[0] = Color.Yellow;
			color[1] = Color.Silver;
			color[2] = Color.FromArgb(80, 100, 80);
			color[3] = Color.Chocolate;
			color[4] = Color.FromArgb(32, 255, 32);
			color[5] = Color.SkyBlue;
			color[6] = Color.Magenta;
			color[7] = Color.FromArgb(80, 80, 255);
			color[8] = Color.Red;
			Pen[] pen = new Pen[9];
			Brush[] brush = new Brush[9];
			for (int i = 0; i < 9; i++) {
				pen[i] = new Pen(color[i], 1);
				brush[i] = new SolidBrush(color[i]);
			}
			// determine price range
			int max = 150;
			for (int i = 0; i < 9; i++) {
				for (int j = 0; j < ((Good) exchange.goods[(int) Good.GoodEnum.Power]).iPriceHistory.Length; j++)
					max = Math.Max(max, ((Good) exchange.goods[i]).iPriceHistory[j]);
			}
			// draw scale
			int iGraphHeight = (picMarket.Height - 10) * 2 / 3;
			int iGraphWidth = picMarket.Width - 65;
			g.DrawLine(Pens.White, 29, 9, 29, iGraphHeight + 10);
			g.DrawLine(Pens.White, 29, 9, iGraphWidth + 31, 9);
			g.DrawLine(Pens.White, iGraphWidth + 31, 9, iGraphWidth + 31, iGraphHeight + 10);
			g.DrawLine(Pens.White, 29, iGraphHeight + 10, iGraphWidth + 31, iGraphHeight + 10);
			for (int i = 0; i < 6; i++) {  // draw price markings
				g.DrawString(((int) (max * i / 5)).ToString(), font2, Brushes.White, picMarket.Width - 20, iGraphHeight * (5 - i) / 5 + 5, format);
				g.DrawString(((int) (max * i / 5)).ToString(), font2, Brushes.White, 15, iGraphHeight * (5 - i) / 5 + 5, format);
			}
			// draw bottom labels
			g.DrawString("Good", font2, Brushes.White, 20, picMarket.Height - 37, format);
			g.DrawString("Price", font2, Brushes.White, 20, picMarket.Height - 22, format);
			for (int i = 0; i < 9; i++) {
				// draw chart line
				int lastprice = ((Good) exchange.goods[i]).iPriceHistory[0];
				for (int j = 0; j < ((Good) exchange.goods[(int) Good.GoodEnum.Power]).iPriceHistory.Length - 1; j++) {
					int price = lastprice;
					lastprice = ((Good) exchange.goods[i]).iPriceHistory[j + 1];
					if (lastprice < 0)
						break;
					else {
						int x1 = iGraphWidth +30 - (int) (iGraphWidth * ((float) j / (float) ((Good) exchange.goods[0]).iPriceHistory.Length));
						int y2 = 10 + (int) (iGraphHeight * (1.0f - (float) lastprice / (float) max));
						int x2 = iGraphWidth + 30 - (int) (iGraphWidth * (float) (j + 1) / (float) ((Good) exchange.goods[0]).iPriceHistory.Length);
						int y1 = 10 + (int) (iGraphHeight * (1.0f - (float) price / (float) max));
						g.DrawLine(pen[i], x1, y1, x2, y2);
					}
				}
				// draw quantity
				g.DrawString(((Good) exchange.goods[i]).strName, font, brush[i], 15 + picMarket.Width * (i + 1) / 10, picMarket.Height - 35, format);
				g.DrawString(((Good) exchange.goods[i]).iPrice.ToString(), font2, brush[i], 15 + picMarket.Width * (i + 1) / 10, picMarket.Height - 20, format);
				int iMarketRectHeight = Math.Max(1, (picMarket.Height - iGraphHeight - 70) * Math.Min(((Good) exchange.goods[i]).iQuantity, 50) / 50);
				g.FillRectangle(brush[i], (int) (picMarket.Width * ((float) i + 0.5) / 10.0) + 15, picMarket.Height - 40 - iMarketRectHeight, picMarket.Width / 20 - 2, iMarketRectHeight);
				g.DrawString(((Good) exchange.goods[i]).iQuantity.ToString(), font2, brush[i], 15 + (int) (picMarket.Width * ((float) i + 0.75) / 10.0), picMarket.Height - 56 - iMarketRectHeight, format);
				if (exchange.agents.Count >= 1) {
					int iPlayerRectHeight = Math.Max(1, (picMarket.Height - iGraphHeight - 70) * Math.Min(((ExchangeAgent) exchange.agents[0]).player.iHoldings[i], 50) / 50);
					g.FillRectangle(brush[i], (int) (picMarket.Width * ((float) i + 1.0) / 10.0) + 14, picMarket.Height - 40 - iPlayerRectHeight, picMarket.Width / 20 - 2, iPlayerRectHeight);
					g.DrawString(((ExchangeAgent) exchange.agents[0]).player.iHoldings[i].ToString(), font2, brush[i], 14 + (int) (picMarket.Width * ((float) i + 1.25) / 10.0), picMarket.Height - 56 - iPlayerRectHeight, format);
				}
			}
		}

		#endregion

		#region Helper functions

		private void UpdateNumbers() {
			// This function updates the credits window, the timer, the scoreboard, and the market chart.
			txtTime.Text = exchange.Time();
			txtStatus.Refresh();
			lblCredits.Text = "Credits:        " + ((ExchangeAgent) exchange.agents[0]).player.iCredits.ToString();
			lblCredits.Refresh();
			// update player stats
			lstScoreboard.BeginUpdate();
			lstScoreboard.Items.Clear();
			for (int i = 1; i <= exchange.agents.Count; i++) {
				for (int j = 0; j < exchange.agents.Count; j++) {
					ExchangeAgent agent = (ExchangeAgent) exchange.agents[j];
					if (agent.player.iRank == i)
						lstScoreboard.Items.Add(new ListViewItem(new string[] { agent.player.iRank.ToString(), agent.player.strName, agent.player.lTotalValue.ToString(), ((Good) exchange.goods[agent.player.iProduction]).strName }));
				}
			}
			lstScoreboard.EndUpdate();
			lstScoreboard.Refresh();
		}

		#endregion

		#region Uninteresting Windows Form Designer generated code

		private void InitializeComponent() {
			this.components = new System.ComponentModel.Container();
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(ExchangeGame));
			this.btnGood1Buy = new System.Windows.Forms.Button();
			this.btnGood1Sell = new System.Windows.Forms.Button();
			this.btnGood2Sell = new System.Windows.Forms.Button();
			this.btnGood2Buy = new System.Windows.Forms.Button();
			this.btnGood3Sell = new System.Windows.Forms.Button();
			this.btnGood3Buy = new System.Windows.Forms.Button();
			this.btnGood4Sell = new System.Windows.Forms.Button();
			this.btnGood4Buy = new System.Windows.Forms.Button();
			this.btnGood5Sell = new System.Windows.Forms.Button();
			this.btnGood5Buy = new System.Windows.Forms.Button();
			this.btnGood6Sell = new System.Windows.Forms.Button();
			this.btnGood6Buy = new System.Windows.Forms.Button();
			this.btnGood7Sell = new System.Windows.Forms.Button();
			this.btnGood7Buy = new System.Windows.Forms.Button();
			this.btnGood8Sell = new System.Windows.Forms.Button();
			this.btnGood8Buy = new System.Windows.Forms.Button();
			this.btnGood9Sell = new System.Windows.Forms.Button();
			this.btnGood9Buy = new System.Windows.Forms.Button();
			this.txtStatus = new System.Windows.Forms.TextBox();
			this.label13 = new System.Windows.Forms.Label();
			this.btnStartStop = new System.Windows.Forms.Button();
			this.timerMarket = new System.Windows.Forms.Timer(this.components);
			this.label56 = new System.Windows.Forms.Label();
			this.rbProduceGood1 = new System.Windows.Forms.RadioButton();
			this.rbProduceGood2 = new System.Windows.Forms.RadioButton();
			this.rbProduceGood3 = new System.Windows.Forms.RadioButton();
			this.rbProduceGood6 = new System.Windows.Forms.RadioButton();
			this.rbProduceGood5 = new System.Windows.Forms.RadioButton();
			this.rbProduceGood4 = new System.Windows.Forms.RadioButton();
			this.rbProduceGood9 = new System.Windows.Forms.RadioButton();
			this.rbProduceGood8 = new System.Windows.Forms.RadioButton();
			this.rbProduceGood7 = new System.Windows.Forms.RadioButton();
			this.grpControls = new System.Windows.Forms.GroupBox();
			this.lblGood9 = new System.Windows.Forms.Label();
			this.lblGood8 = new System.Windows.Forms.Label();
			this.lblGood7 = new System.Windows.Forms.Label();
			this.lblGood6 = new System.Windows.Forms.Label();
			this.lblGood5 = new System.Windows.Forms.Label();
			this.lblGood4 = new System.Windows.Forms.Label();
			this.lblGood3 = new System.Windows.Forms.Label();
			this.lblGood2 = new System.Windows.Forms.Label();
			this.lblGood1 = new System.Windows.Forms.Label();
			this.label1 = new System.Windows.Forms.Label();
			this.btnGood6Sell10 = new System.Windows.Forms.Button();
			this.btnGood7Sell10 = new System.Windows.Forms.Button();
			this.btnGood8Sell10 = new System.Windows.Forms.Button();
			this.btnGood9Sell10 = new System.Windows.Forms.Button();
			this.btnGood5Sell10 = new System.Windows.Forms.Button();
			this.btnGood4Sell10 = new System.Windows.Forms.Button();
			this.btnGood3Sell10 = new System.Windows.Forms.Button();
			this.btnGood2Sell10 = new System.Windows.Forms.Button();
			this.btnGood1Sell10 = new System.Windows.Forms.Button();
			this.btnGood6Buy10 = new System.Windows.Forms.Button();
			this.btnGood7Buy10 = new System.Windows.Forms.Button();
			this.btnGood8Buy10 = new System.Windows.Forms.Button();
			this.btnGood9Buy10 = new System.Windows.Forms.Button();
			this.btnGood5Buy10 = new System.Windows.Forms.Button();
			this.btnGood4Buy10 = new System.Windows.Forms.Button();
			this.btnGood3Buy10 = new System.Windows.Forms.Button();
			this.btnGood2Buy10 = new System.Windows.Forms.Button();
			this.btnGood1Buy10 = new System.Windows.Forms.Button();
			this.txtTime = new System.Windows.Forms.TextBox();
			this.lstScoreboard = new System.Windows.Forms.ListView();
			this.headerRank = new System.Windows.Forms.ColumnHeader();
			this.headerName = new System.Windows.Forms.ColumnHeader();
			this.headerValue = new System.Windows.Forms.ColumnHeader();
			this.headerProduction = new System.Windows.Forms.ColumnHeader();
			this.grpRankings = new System.Windows.Forms.GroupBox();
			this.timerTicker = new System.Windows.Forms.Timer(this.components);
			this.picMarket = new System.Windows.Forms.PictureBox();
			this.lblCredits = new System.Windows.Forms.Label();
			this.grpControls.SuspendLayout();
			this.grpRankings.SuspendLayout();
			this.SuspendLayout();
			// 
			// btnGood1Buy
			// 
			this.btnGood1Buy.Location = new System.Drawing.Point(152, 48);
			this.btnGood1Buy.Name = "btnGood1Buy";
			this.btnGood1Buy.Size = new System.Drawing.Size(32, 23);
			this.btnGood1Buy.TabIndex = 2;
			this.btnGood1Buy.Text = "+1";
			this.btnGood1Buy.Click += new System.EventHandler(this.btnGoodBuy_Click);
			// 
			// btnGood1Sell
			// 
			this.btnGood1Sell.Location = new System.Drawing.Point(192, 48);
			this.btnGood1Sell.Name = "btnGood1Sell";
			this.btnGood1Sell.Size = new System.Drawing.Size(32, 23);
			this.btnGood1Sell.TabIndex = 3;
			this.btnGood1Sell.Text = "-1";
			this.btnGood1Sell.Click += new System.EventHandler(this.btnGoodSell_Click);
			// 
			// btnGood2Sell
			// 
			this.btnGood2Sell.Location = new System.Drawing.Point(192, 80);
			this.btnGood2Sell.Name = "btnGood2Sell";
			this.btnGood2Sell.Size = new System.Drawing.Size(32, 23);
			this.btnGood2Sell.TabIndex = 7;
			this.btnGood2Sell.Text = "-1";
			this.btnGood2Sell.Click += new System.EventHandler(this.btnGoodSell_Click);
			// 
			// btnGood2Buy
			// 
			this.btnGood2Buy.Location = new System.Drawing.Point(152, 80);
			this.btnGood2Buy.Name = "btnGood2Buy";
			this.btnGood2Buy.Size = new System.Drawing.Size(32, 23);
			this.btnGood2Buy.TabIndex = 6;
			this.btnGood2Buy.Text = "+1";
			this.btnGood2Buy.Click += new System.EventHandler(this.btnGoodBuy_Click);
			// 
			// btnGood3Sell
			// 
			this.btnGood3Sell.Location = new System.Drawing.Point(192, 112);
			this.btnGood3Sell.Name = "btnGood3Sell";
			this.btnGood3Sell.Size = new System.Drawing.Size(32, 23);
			this.btnGood3Sell.TabIndex = 11;
			this.btnGood3Sell.Text = "-1";
			this.btnGood3Sell.Click += new System.EventHandler(this.btnGoodSell_Click);
			// 
			// btnGood3Buy
			// 
			this.btnGood3Buy.Location = new System.Drawing.Point(152, 112);
			this.btnGood3Buy.Name = "btnGood3Buy";
			this.btnGood3Buy.Size = new System.Drawing.Size(32, 23);
			this.btnGood3Buy.TabIndex = 10;
			this.btnGood3Buy.Text = "+1";
			this.btnGood3Buy.Click += new System.EventHandler(this.btnGoodBuy_Click);
			// 
			// btnGood4Sell
			// 
			this.btnGood4Sell.Location = new System.Drawing.Point(192, 144);
			this.btnGood4Sell.Name = "btnGood4Sell";
			this.btnGood4Sell.Size = new System.Drawing.Size(32, 23);
			this.btnGood4Sell.TabIndex = 15;
			this.btnGood4Sell.Text = "-1";
			this.btnGood4Sell.Click += new System.EventHandler(this.btnGoodSell_Click);
			// 
			// btnGood4Buy
			// 
			this.btnGood4Buy.Location = new System.Drawing.Point(152, 144);
			this.btnGood4Buy.Name = "btnGood4Buy";
			this.btnGood4Buy.Size = new System.Drawing.Size(32, 23);
			this.btnGood4Buy.TabIndex = 14;
			this.btnGood4Buy.Text = "+1";
			this.btnGood4Buy.Click += new System.EventHandler(this.btnGoodBuy_Click);
			// 
			// btnGood5Sell
			// 
			this.btnGood5Sell.Location = new System.Drawing.Point(192, 176);
			this.btnGood5Sell.Name = "btnGood5Sell";
			this.btnGood5Sell.Size = new System.Drawing.Size(32, 23);
			this.btnGood5Sell.TabIndex = 19;
			this.btnGood5Sell.Text = "-1";
			this.btnGood5Sell.Click += new System.EventHandler(this.btnGoodSell_Click);
			// 
			// btnGood5Buy
			// 
			this.btnGood5Buy.Location = new System.Drawing.Point(152, 176);
			this.btnGood5Buy.Name = "btnGood5Buy";
			this.btnGood5Buy.Size = new System.Drawing.Size(32, 23);
			this.btnGood5Buy.TabIndex = 18;
			this.btnGood5Buy.Text = "+1";
			this.btnGood5Buy.Click += new System.EventHandler(this.btnGoodBuy_Click);
			// 
			// btnGood6Sell
			// 
			this.btnGood6Sell.Location = new System.Drawing.Point(192, 208);
			this.btnGood6Sell.Name = "btnGood6Sell";
			this.btnGood6Sell.Size = new System.Drawing.Size(32, 23);
			this.btnGood6Sell.TabIndex = 23;
			this.btnGood6Sell.Text = "-1";
			this.btnGood6Sell.Click += new System.EventHandler(this.btnGoodSell_Click);
			// 
			// btnGood6Buy
			// 
			this.btnGood6Buy.Location = new System.Drawing.Point(152, 208);
			this.btnGood6Buy.Name = "btnGood6Buy";
			this.btnGood6Buy.Size = new System.Drawing.Size(32, 23);
			this.btnGood6Buy.TabIndex = 22;
			this.btnGood6Buy.Text = "+1";
			this.btnGood6Buy.Click += new System.EventHandler(this.btnGoodBuy_Click);
			// 
			// btnGood7Sell
			// 
			this.btnGood7Sell.Location = new System.Drawing.Point(192, 240);
			this.btnGood7Sell.Name = "btnGood7Sell";
			this.btnGood7Sell.Size = new System.Drawing.Size(32, 23);
			this.btnGood7Sell.TabIndex = 27;
			this.btnGood7Sell.Text = "-1";
			this.btnGood7Sell.Click += new System.EventHandler(this.btnGoodSell_Click);
			// 
			// btnGood7Buy
			// 
			this.btnGood7Buy.Location = new System.Drawing.Point(152, 240);
			this.btnGood7Buy.Name = "btnGood7Buy";
			this.btnGood7Buy.Size = new System.Drawing.Size(32, 23);
			this.btnGood7Buy.TabIndex = 26;
			this.btnGood7Buy.Text = "+1";
			this.btnGood7Buy.Click += new System.EventHandler(this.btnGoodBuy_Click);
			// 
			// btnGood8Sell
			// 
			this.btnGood8Sell.Location = new System.Drawing.Point(192, 272);
			this.btnGood8Sell.Name = "btnGood8Sell";
			this.btnGood8Sell.Size = new System.Drawing.Size(32, 23);
			this.btnGood8Sell.TabIndex = 31;
			this.btnGood8Sell.Text = "-1";
			this.btnGood8Sell.Click += new System.EventHandler(this.btnGoodSell_Click);
			// 
			// btnGood8Buy
			// 
			this.btnGood8Buy.Location = new System.Drawing.Point(152, 272);
			this.btnGood8Buy.Name = "btnGood8Buy";
			this.btnGood8Buy.Size = new System.Drawing.Size(32, 23);
			this.btnGood8Buy.TabIndex = 30;
			this.btnGood8Buy.Text = "+1";
			this.btnGood8Buy.Click += new System.EventHandler(this.btnGoodBuy_Click);
			// 
			// btnGood9Sell
			// 
			this.btnGood9Sell.Location = new System.Drawing.Point(192, 304);
			this.btnGood9Sell.Name = "btnGood9Sell";
			this.btnGood9Sell.Size = new System.Drawing.Size(32, 23);
			this.btnGood9Sell.TabIndex = 35;
			this.btnGood9Sell.Text = "-1";
			this.btnGood9Sell.Click += new System.EventHandler(this.btnGoodSell_Click);
			// 
			// btnGood9Buy
			// 
			this.btnGood9Buy.Location = new System.Drawing.Point(152, 304);
			this.btnGood9Buy.Name = "btnGood9Buy";
			this.btnGood9Buy.Size = new System.Drawing.Size(32, 23);
			this.btnGood9Buy.TabIndex = 34;
			this.btnGood9Buy.Text = "+1";
			this.btnGood9Buy.Click += new System.EventHandler(this.btnGoodBuy_Click);
			// 
			// txtStatus
			// 
			this.txtStatus.Anchor = System.Windows.Forms.AnchorStyles.Bottom;
			this.txtStatus.Font = new System.Drawing.Font("Courier New", 14.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.txtStatus.Location = new System.Drawing.Point(120, 696);
			this.txtStatus.Name = "txtStatus";
			this.txtStatus.ReadOnly = true;
			this.txtStatus.Size = new System.Drawing.Size(752, 29);
			this.txtStatus.TabIndex = 57;
			this.txtStatus.Text = "------------------------------------------------------------------- * The Exchang" +
				"e * Press Start To Begin * ";
			// 
			// label13
			// 
			this.label13.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
			this.label13.Location = new System.Drawing.Point(120, 16);
			this.label13.Name = "label13";
			this.label13.Size = new System.Drawing.Size(64, 23);
			this.label13.TabIndex = 58;
			this.label13.Text = "Buy";
			this.label13.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// btnStartStop
			// 
			this.btnStartStop.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
			this.btnStartStop.Location = new System.Drawing.Point(8, 16);
			this.btnStartStop.Name = "btnStartStop";
			this.btnStartStop.Size = new System.Drawing.Size(104, 23);
			this.btnStartStop.TabIndex = 0;
			this.btnStartStop.Text = "Start";
			this.btnStartStop.Click += new System.EventHandler(this.btnStartStop_Click);
			// 
			// timerMarket
			// 
			this.timerMarket.Interval = 1000;
			this.timerMarket.Tick += new System.EventHandler(this.timerMarket_Tick);
			// 
			// label56
			// 
			this.label56.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
			this.label56.Location = new System.Drawing.Point(264, 16);
			this.label56.Name = "label56";
			this.label56.Size = new System.Drawing.Size(64, 23);
			this.label56.TabIndex = 61;
			this.label56.Text = "Production";
			this.label56.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// rbProduceGood1
			// 
			this.rbProduceGood1.CheckAlign = System.Drawing.ContentAlignment.MiddleCenter;
			this.rbProduceGood1.Checked = true;
			this.rbProduceGood1.Location = new System.Drawing.Point(288, 48);
			this.rbProduceGood1.Name = "rbProduceGood1";
			this.rbProduceGood1.Size = new System.Drawing.Size(16, 24);
			this.rbProduceGood1.TabIndex = 37;
			this.rbProduceGood1.TabStop = true;
			this.rbProduceGood1.CheckedChanged += new System.EventHandler(this.rbProduceGood_CheckedChanged);
			// 
			// rbProduceGood2
			// 
			this.rbProduceGood2.CheckAlign = System.Drawing.ContentAlignment.MiddleCenter;
			this.rbProduceGood2.Location = new System.Drawing.Point(288, 80);
			this.rbProduceGood2.Name = "rbProduceGood2";
			this.rbProduceGood2.Size = new System.Drawing.Size(16, 24);
			this.rbProduceGood2.TabIndex = 38;
			this.rbProduceGood2.CheckedChanged += new System.EventHandler(this.rbProduceGood_CheckedChanged);
			// 
			// rbProduceGood3
			// 
			this.rbProduceGood3.CheckAlign = System.Drawing.ContentAlignment.MiddleCenter;
			this.rbProduceGood3.Location = new System.Drawing.Point(288, 112);
			this.rbProduceGood3.Name = "rbProduceGood3";
			this.rbProduceGood3.Size = new System.Drawing.Size(16, 24);
			this.rbProduceGood3.TabIndex = 39;
			this.rbProduceGood3.CheckedChanged += new System.EventHandler(this.rbProduceGood_CheckedChanged);
			// 
			// rbProduceGood6
			// 
			this.rbProduceGood6.CheckAlign = System.Drawing.ContentAlignment.MiddleCenter;
			this.rbProduceGood6.Location = new System.Drawing.Point(288, 208);
			this.rbProduceGood6.Name = "rbProduceGood6";
			this.rbProduceGood6.Size = new System.Drawing.Size(16, 24);
			this.rbProduceGood6.TabIndex = 42;
			this.rbProduceGood6.CheckedChanged += new System.EventHandler(this.rbProduceGood_CheckedChanged);
			// 
			// rbProduceGood5
			// 
			this.rbProduceGood5.CheckAlign = System.Drawing.ContentAlignment.MiddleCenter;
			this.rbProduceGood5.Location = new System.Drawing.Point(288, 176);
			this.rbProduceGood5.Name = "rbProduceGood5";
			this.rbProduceGood5.Size = new System.Drawing.Size(16, 24);
			this.rbProduceGood5.TabIndex = 41;
			this.rbProduceGood5.CheckedChanged += new System.EventHandler(this.rbProduceGood_CheckedChanged);
			// 
			// rbProduceGood4
			// 
			this.rbProduceGood4.CheckAlign = System.Drawing.ContentAlignment.MiddleCenter;
			this.rbProduceGood4.Location = new System.Drawing.Point(288, 144);
			this.rbProduceGood4.Name = "rbProduceGood4";
			this.rbProduceGood4.Size = new System.Drawing.Size(16, 24);
			this.rbProduceGood4.TabIndex = 40;
			this.rbProduceGood4.CheckedChanged += new System.EventHandler(this.rbProduceGood_CheckedChanged);
			// 
			// rbProduceGood9
			// 
			this.rbProduceGood9.CheckAlign = System.Drawing.ContentAlignment.MiddleCenter;
			this.rbProduceGood9.Location = new System.Drawing.Point(288, 304);
			this.rbProduceGood9.Name = "rbProduceGood9";
			this.rbProduceGood9.Size = new System.Drawing.Size(16, 24);
			this.rbProduceGood9.TabIndex = 45;
			this.rbProduceGood9.CheckedChanged += new System.EventHandler(this.rbProduceGood_CheckedChanged);
			// 
			// rbProduceGood8
			// 
			this.rbProduceGood8.CheckAlign = System.Drawing.ContentAlignment.MiddleCenter;
			this.rbProduceGood8.Location = new System.Drawing.Point(288, 272);
			this.rbProduceGood8.Name = "rbProduceGood8";
			this.rbProduceGood8.Size = new System.Drawing.Size(16, 24);
			this.rbProduceGood8.TabIndex = 44;
			this.rbProduceGood8.CheckedChanged += new System.EventHandler(this.rbProduceGood_CheckedChanged);
			// 
			// rbProduceGood7
			// 
			this.rbProduceGood7.CheckAlign = System.Drawing.ContentAlignment.MiddleCenter;
			this.rbProduceGood7.Location = new System.Drawing.Point(288, 240);
			this.rbProduceGood7.Name = "rbProduceGood7";
			this.rbProduceGood7.Size = new System.Drawing.Size(16, 24);
			this.rbProduceGood7.TabIndex = 43;
			this.rbProduceGood7.CheckedChanged += new System.EventHandler(this.rbProduceGood_CheckedChanged);
			// 
			// grpControls
			// 
			this.grpControls.Controls.Add(this.lblGood9);
			this.grpControls.Controls.Add(this.lblGood8);
			this.grpControls.Controls.Add(this.lblGood7);
			this.grpControls.Controls.Add(this.lblGood6);
			this.grpControls.Controls.Add(this.lblGood5);
			this.grpControls.Controls.Add(this.lblGood4);
			this.grpControls.Controls.Add(this.lblGood3);
			this.grpControls.Controls.Add(this.lblGood2);
			this.grpControls.Controls.Add(this.lblGood1);
			this.grpControls.Controls.Add(this.label1);
			this.grpControls.Controls.Add(this.btnGood6Sell10);
			this.grpControls.Controls.Add(this.btnGood7Sell10);
			this.grpControls.Controls.Add(this.btnGood8Sell10);
			this.grpControls.Controls.Add(this.btnGood9Sell10);
			this.grpControls.Controls.Add(this.btnGood5Sell10);
			this.grpControls.Controls.Add(this.btnGood4Sell10);
			this.grpControls.Controls.Add(this.btnGood3Sell10);
			this.grpControls.Controls.Add(this.btnGood2Sell10);
			this.grpControls.Controls.Add(this.btnGood1Sell10);
			this.grpControls.Controls.Add(this.btnGood6Buy10);
			this.grpControls.Controls.Add(this.btnGood7Buy10);
			this.grpControls.Controls.Add(this.btnGood8Buy10);
			this.grpControls.Controls.Add(this.btnGood9Buy10);
			this.grpControls.Controls.Add(this.btnGood5Buy10);
			this.grpControls.Controls.Add(this.btnGood4Buy10);
			this.grpControls.Controls.Add(this.btnGood3Buy10);
			this.grpControls.Controls.Add(this.btnGood2Buy10);
			this.grpControls.Controls.Add(this.btnGood1Buy10);
			this.grpControls.Controls.Add(this.label13);
			this.grpControls.Controls.Add(this.label56);
			this.grpControls.Controls.Add(this.rbProduceGood1);
			this.grpControls.Controls.Add(this.rbProduceGood2);
			this.grpControls.Controls.Add(this.rbProduceGood3);
			this.grpControls.Controls.Add(this.rbProduceGood6);
			this.grpControls.Controls.Add(this.rbProduceGood5);
			this.grpControls.Controls.Add(this.rbProduceGood4);
			this.grpControls.Controls.Add(this.rbProduceGood9);
			this.grpControls.Controls.Add(this.rbProduceGood8);
			this.grpControls.Controls.Add(this.rbProduceGood7);
			this.grpControls.Controls.Add(this.btnGood6Sell);
			this.grpControls.Controls.Add(this.btnGood6Buy);
			this.grpControls.Controls.Add(this.btnGood7Sell);
			this.grpControls.Controls.Add(this.btnGood7Buy);
			this.grpControls.Controls.Add(this.btnGood8Sell);
			this.grpControls.Controls.Add(this.btnGood8Buy);
			this.grpControls.Controls.Add(this.btnGood9Sell);
			this.grpControls.Controls.Add(this.btnGood9Buy);
			this.grpControls.Controls.Add(this.btnGood5Buy);
			this.grpControls.Controls.Add(this.btnGood5Sell);
			this.grpControls.Controls.Add(this.btnGood4Buy);
			this.grpControls.Controls.Add(this.btnGood4Sell);
			this.grpControls.Controls.Add(this.btnGood3Buy);
			this.grpControls.Controls.Add(this.btnGood3Sell);
			this.grpControls.Controls.Add(this.btnGood2Buy);
			this.grpControls.Controls.Add(this.btnGood2Sell);
			this.grpControls.Controls.Add(this.btnGood1Sell);
			this.grpControls.Controls.Add(this.btnGood1Buy);
			this.grpControls.Controls.Add(this.btnStartStop);
			this.grpControls.Location = new System.Drawing.Point(8, 8);
			this.grpControls.Name = "grpControls";
			this.grpControls.Size = new System.Drawing.Size(336, 344);
			this.grpControls.TabIndex = 0;
			this.grpControls.TabStop = false;
			this.grpControls.Text = "Controls";
			// 
			// lblGood9
			// 
			this.lblGood9.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
			this.lblGood9.Location = new System.Drawing.Point(8, 304);
			this.lblGood9.Name = "lblGood9";
			this.lblGood9.Size = new System.Drawing.Size(104, 23);
			this.lblGood9.TabIndex = 98;
			this.lblGood9.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// lblGood8
			// 
			this.lblGood8.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
			this.lblGood8.Location = new System.Drawing.Point(8, 272);
			this.lblGood8.Name = "lblGood8";
			this.lblGood8.Size = new System.Drawing.Size(104, 23);
			this.lblGood8.TabIndex = 97;
			this.lblGood8.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// lblGood7
			// 
			this.lblGood7.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
			this.lblGood7.Location = new System.Drawing.Point(8, 240);
			this.lblGood7.Name = "lblGood7";
			this.lblGood7.Size = new System.Drawing.Size(104, 23);
			this.lblGood7.TabIndex = 96;
			this.lblGood7.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// lblGood6
			// 
			this.lblGood6.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
			this.lblGood6.Location = new System.Drawing.Point(8, 208);
			this.lblGood6.Name = "lblGood6";
			this.lblGood6.Size = new System.Drawing.Size(104, 23);
			this.lblGood6.TabIndex = 95;
			this.lblGood6.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// lblGood5
			// 
			this.lblGood5.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
			this.lblGood5.Location = new System.Drawing.Point(8, 176);
			this.lblGood5.Name = "lblGood5";
			this.lblGood5.Size = new System.Drawing.Size(104, 23);
			this.lblGood5.TabIndex = 94;
			this.lblGood5.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// lblGood4
			// 
			this.lblGood4.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
			this.lblGood4.Location = new System.Drawing.Point(8, 144);
			this.lblGood4.Name = "lblGood4";
			this.lblGood4.Size = new System.Drawing.Size(104, 23);
			this.lblGood4.TabIndex = 93;
			this.lblGood4.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// lblGood3
			// 
			this.lblGood3.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
			this.lblGood3.Location = new System.Drawing.Point(8, 112);
			this.lblGood3.Name = "lblGood3";
			this.lblGood3.Size = new System.Drawing.Size(104, 23);
			this.lblGood3.TabIndex = 92;
			this.lblGood3.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// lblGood2
			// 
			this.lblGood2.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
			this.lblGood2.Location = new System.Drawing.Point(8, 80);
			this.lblGood2.Name = "lblGood2";
			this.lblGood2.Size = new System.Drawing.Size(104, 23);
			this.lblGood2.TabIndex = 91;
			this.lblGood2.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// lblGood1
			// 
			this.lblGood1.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
			this.lblGood1.Location = new System.Drawing.Point(8, 48);
			this.lblGood1.Name = "lblGood1";
			this.lblGood1.Size = new System.Drawing.Size(104, 23);
			this.lblGood1.TabIndex = 90;
			this.lblGood1.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// label1
			// 
			this.label1.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
			this.label1.Location = new System.Drawing.Point(192, 16);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(64, 23);
			this.label1.TabIndex = 89;
			this.label1.Text = "Sell";
			this.label1.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// btnGood6Sell10
			// 
			this.btnGood6Sell10.Location = new System.Drawing.Point(224, 208);
			this.btnGood6Sell10.Name = "btnGood6Sell10";
			this.btnGood6Sell10.Size = new System.Drawing.Size(32, 23);
			this.btnGood6Sell10.TabIndex = 24;
			this.btnGood6Sell10.Text = "-10";
			this.btnGood6Sell10.Click += new System.EventHandler(this.btnGoodSell_Click);
			// 
			// btnGood7Sell10
			// 
			this.btnGood7Sell10.Location = new System.Drawing.Point(224, 240);
			this.btnGood7Sell10.Name = "btnGood7Sell10";
			this.btnGood7Sell10.Size = new System.Drawing.Size(32, 23);
			this.btnGood7Sell10.TabIndex = 28;
			this.btnGood7Sell10.Text = "-10";
			this.btnGood7Sell10.Click += new System.EventHandler(this.btnGoodSell_Click);
			// 
			// btnGood8Sell10
			// 
			this.btnGood8Sell10.Location = new System.Drawing.Point(224, 272);
			this.btnGood8Sell10.Name = "btnGood8Sell10";
			this.btnGood8Sell10.Size = new System.Drawing.Size(32, 23);
			this.btnGood8Sell10.TabIndex = 32;
			this.btnGood8Sell10.Text = "-10";
			this.btnGood8Sell10.Click += new System.EventHandler(this.btnGoodSell_Click);
			// 
			// btnGood9Sell10
			// 
			this.btnGood9Sell10.Location = new System.Drawing.Point(224, 304);
			this.btnGood9Sell10.Name = "btnGood9Sell10";
			this.btnGood9Sell10.Size = new System.Drawing.Size(32, 23);
			this.btnGood9Sell10.TabIndex = 36;
			this.btnGood9Sell10.Text = "-10";
			this.btnGood9Sell10.Click += new System.EventHandler(this.btnGoodSell_Click);
			// 
			// btnGood5Sell10
			// 
			this.btnGood5Sell10.Location = new System.Drawing.Point(224, 176);
			this.btnGood5Sell10.Name = "btnGood5Sell10";
			this.btnGood5Sell10.Size = new System.Drawing.Size(32, 23);
			this.btnGood5Sell10.TabIndex = 20;
			this.btnGood5Sell10.Text = "-10";
			this.btnGood5Sell10.Click += new System.EventHandler(this.btnGoodSell_Click);
			// 
			// btnGood4Sell10
			// 
			this.btnGood4Sell10.Location = new System.Drawing.Point(224, 144);
			this.btnGood4Sell10.Name = "btnGood4Sell10";
			this.btnGood4Sell10.Size = new System.Drawing.Size(32, 23);
			this.btnGood4Sell10.TabIndex = 16;
			this.btnGood4Sell10.Text = "-10";
			this.btnGood4Sell10.Click += new System.EventHandler(this.btnGoodSell_Click);
			// 
			// btnGood3Sell10
			// 
			this.btnGood3Sell10.Location = new System.Drawing.Point(224, 112);
			this.btnGood3Sell10.Name = "btnGood3Sell10";
			this.btnGood3Sell10.Size = new System.Drawing.Size(32, 23);
			this.btnGood3Sell10.TabIndex = 12;
			this.btnGood3Sell10.Text = "-10";
			this.btnGood3Sell10.Click += new System.EventHandler(this.btnGoodSell_Click);
			// 
			// btnGood2Sell10
			// 
			this.btnGood2Sell10.Location = new System.Drawing.Point(224, 80);
			this.btnGood2Sell10.Name = "btnGood2Sell10";
			this.btnGood2Sell10.Size = new System.Drawing.Size(32, 23);
			this.btnGood2Sell10.TabIndex = 8;
			this.btnGood2Sell10.Text = "-10";
			this.btnGood2Sell10.Click += new System.EventHandler(this.btnGoodSell_Click);
			// 
			// btnGood1Sell10
			// 
			this.btnGood1Sell10.Location = new System.Drawing.Point(224, 48);
			this.btnGood1Sell10.Name = "btnGood1Sell10";
			this.btnGood1Sell10.Size = new System.Drawing.Size(32, 23);
			this.btnGood1Sell10.TabIndex = 4;
			this.btnGood1Sell10.Text = "-10";
			this.btnGood1Sell10.Click += new System.EventHandler(this.btnGoodSell_Click);
			// 
			// btnGood6Buy10
			// 
			this.btnGood6Buy10.Location = new System.Drawing.Point(120, 208);
			this.btnGood6Buy10.Name = "btnGood6Buy10";
			this.btnGood6Buy10.Size = new System.Drawing.Size(32, 23);
			this.btnGood6Buy10.TabIndex = 21;
			this.btnGood6Buy10.Text = "+10";
			this.btnGood6Buy10.Click += new System.EventHandler(this.btnGoodBuy_Click);
			// 
			// btnGood7Buy10
			// 
			this.btnGood7Buy10.Location = new System.Drawing.Point(120, 240);
			this.btnGood7Buy10.Name = "btnGood7Buy10";
			this.btnGood7Buy10.Size = new System.Drawing.Size(32, 23);
			this.btnGood7Buy10.TabIndex = 25;
			this.btnGood7Buy10.Text = "+10";
			this.btnGood7Buy10.Click += new System.EventHandler(this.btnGoodBuy_Click);
			// 
			// btnGood8Buy10
			// 
			this.btnGood8Buy10.Location = new System.Drawing.Point(120, 272);
			this.btnGood8Buy10.Name = "btnGood8Buy10";
			this.btnGood8Buy10.Size = new System.Drawing.Size(32, 23);
			this.btnGood8Buy10.TabIndex = 29;
			this.btnGood8Buy10.Text = "+10";
			this.btnGood8Buy10.Click += new System.EventHandler(this.btnGoodBuy_Click);
			// 
			// btnGood9Buy10
			// 
			this.btnGood9Buy10.Location = new System.Drawing.Point(120, 304);
			this.btnGood9Buy10.Name = "btnGood9Buy10";
			this.btnGood9Buy10.Size = new System.Drawing.Size(32, 23);
			this.btnGood9Buy10.TabIndex = 33;
			this.btnGood9Buy10.Text = "+10";
			this.btnGood9Buy10.Click += new System.EventHandler(this.btnGoodBuy_Click);
			// 
			// btnGood5Buy10
			// 
			this.btnGood5Buy10.Location = new System.Drawing.Point(120, 176);
			this.btnGood5Buy10.Name = "btnGood5Buy10";
			this.btnGood5Buy10.Size = new System.Drawing.Size(32, 23);
			this.btnGood5Buy10.TabIndex = 17;
			this.btnGood5Buy10.Text = "+10";
			this.btnGood5Buy10.Click += new System.EventHandler(this.btnGoodBuy_Click);
			// 
			// btnGood4Buy10
			// 
			this.btnGood4Buy10.Location = new System.Drawing.Point(120, 144);
			this.btnGood4Buy10.Name = "btnGood4Buy10";
			this.btnGood4Buy10.Size = new System.Drawing.Size(32, 23);
			this.btnGood4Buy10.TabIndex = 13;
			this.btnGood4Buy10.Text = "+10";
			this.btnGood4Buy10.Click += new System.EventHandler(this.btnGoodBuy_Click);
			// 
			// btnGood3Buy10
			// 
			this.btnGood3Buy10.Location = new System.Drawing.Point(120, 112);
			this.btnGood3Buy10.Name = "btnGood3Buy10";
			this.btnGood3Buy10.Size = new System.Drawing.Size(32, 23);
			this.btnGood3Buy10.TabIndex = 9;
			this.btnGood3Buy10.Text = "+10";
			this.btnGood3Buy10.Click += new System.EventHandler(this.btnGoodBuy_Click);
			// 
			// btnGood2Buy10
			// 
			this.btnGood2Buy10.Location = new System.Drawing.Point(120, 80);
			this.btnGood2Buy10.Name = "btnGood2Buy10";
			this.btnGood2Buy10.Size = new System.Drawing.Size(32, 23);
			this.btnGood2Buy10.TabIndex = 5;
			this.btnGood2Buy10.Text = "+10";
			this.btnGood2Buy10.Click += new System.EventHandler(this.btnGoodBuy_Click);
			// 
			// btnGood1Buy10
			// 
			this.btnGood1Buy10.Location = new System.Drawing.Point(120, 48);
			this.btnGood1Buy10.Name = "btnGood1Buy10";
			this.btnGood1Buy10.Size = new System.Drawing.Size(32, 23);
			this.btnGood1Buy10.TabIndex = 1;
			this.btnGood1Buy10.Text = "+10";
			this.btnGood1Buy10.Click += new System.EventHandler(this.btnGoodBuy_Click);
			// 
			// txtTime
			// 
			this.txtTime.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
			this.txtTime.Font = new System.Drawing.Font("Courier New", 14.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.txtTime.Location = new System.Drawing.Point(880, 696);
			this.txtTime.Name = "txtTime";
			this.txtTime.ReadOnly = true;
			this.txtTime.Size = new System.Drawing.Size(104, 29);
			this.txtTime.TabIndex = 73;
			this.txtTime.Text = "0:0:0";
			this.txtTime.TextAlign = System.Windows.Forms.HorizontalAlignment.Center;
			// 
			// lstScoreboard
			// 
			this.lstScoreboard.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
				| System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.lstScoreboard.Columns.AddRange(new System.Windows.Forms.ColumnHeader[] {
																													 this.headerRank,
																													 this.headerName,
																													 this.headerValue,
																													 this.headerProduction});
			this.lstScoreboard.FullRowSelect = true;
			this.lstScoreboard.Location = new System.Drawing.Point(8, 16);
			this.lstScoreboard.Name = "lstScoreboard";
			this.lstScoreboard.Size = new System.Drawing.Size(320, 304);
			this.lstScoreboard.TabIndex = 0;
			this.lstScoreboard.View = System.Windows.Forms.View.Details;
			this.lstScoreboard.Click += new System.EventHandler(this.lstScoreboard_Click);
			// 
			// headerRank
			// 
			this.headerRank.Text = "Rank";
			this.headerRank.Width = 40;
			// 
			// headerName
			// 
			this.headerName.Text = "Name";
			this.headerName.Width = 110;
			// 
			// headerValue
			// 
			this.headerValue.Text = "Value";
			// 
			// headerProduction
			// 
			this.headerProduction.Text = "Production";
			this.headerProduction.Width = 80;
			// 
			// grpRankings
			// 
			this.grpRankings.Controls.Add(this.lstScoreboard);
			this.grpRankings.Location = new System.Drawing.Point(8, 360);
			this.grpRankings.Name = "grpRankings";
			this.grpRankings.Size = new System.Drawing.Size(336, 328);
			this.grpRankings.TabIndex = 75;
			this.grpRankings.TabStop = false;
			this.grpRankings.Text = "Rankings";
			// 
			// timerTicker
			// 
			this.timerTicker.Enabled = true;
			this.timerTicker.Interval = 120;
			this.timerTicker.Tick += new System.EventHandler(this.timerTicker_Tick);
			// 
			// picMarket
			// 
			this.picMarket.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
				| System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.picMarket.BorderStyle = System.Windows.Forms.BorderStyle.Fixed3D;
			this.picMarket.Location = new System.Drawing.Point(352, 8);
			this.picMarket.Name = "picMarket";
			this.picMarket.Size = new System.Drawing.Size(632, 680);
			this.picMarket.TabIndex = 76;
			this.picMarket.TabStop = false;
			this.picMarket.Paint += new System.Windows.Forms.PaintEventHandler(this.picMarket_Paint);
			// 
			// lblCredits
			// 
			this.lblCredits.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
			this.lblCredits.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
			this.lblCredits.Font = new System.Drawing.Font("Courier New", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblCredits.Location = new System.Drawing.Point(8, 696);
			this.lblCredits.Name = "lblCredits";
			this.lblCredits.Size = new System.Drawing.Size(104, 29);
			this.lblCredits.TabIndex = 99;
			this.lblCredits.Text = "Credits:        1000";
			this.lblCredits.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// ExchangeGame
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(992, 734);
			this.Controls.Add(this.picMarket);
			this.Controls.Add(this.grpRankings);
			this.Controls.Add(this.txtTime);
			this.Controls.Add(this.grpControls);
			this.Controls.Add(this.txtStatus);
			this.Controls.Add(this.lblCredits);
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.Name = "ExchangeGame";
			this.Text = "The Exchange";
			this.grpControls.ResumeLayout(false);
			this.grpRankings.ResumeLayout(false);
			this.ResumeLayout(false);

		}

		protected override void Dispose(bool disposing) {
			if (disposing) {
				if (components != null) {
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#endregion

	}
}
