// The Exchange: Genetically Evolving Market Agents 
// Written by David J. Stein, Esq., 11/22/2004. See "License.html" for terms and conditions of use.
//
// This module contains the code for the form that displays an agent.

#region Using declarations

using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

#endregion

namespace The_Exchange_Namespace {

	public class ExchangeAgentDisplayDialog : System.Windows.Forms.Form	{
		// This class represents the form for displaying the contents of an agent.

		#region Variables and initialization code

		private ExchangeAgent agent;
		private System.ComponentModel.Container components = null;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.ListBox lstProgram;
		private System.Windows.Forms.Button btnOK;
		private System.Windows.Forms.Label label6;
		private System.Windows.Forms.TextBox txtName;
		private System.Windows.Forms.TextBox txtType;
		private System.Windows.Forms.TextBox txtPlayed;
		private System.Windows.Forms.TextBox txtFitness;
		private System.Windows.Forms.Label label5;
		private System.Windows.Forms.TextBox txtRank;
		private System.Windows.Forms.Label label7;
		private System.Windows.Forms.TextBox txtValue;
		private System.Windows.Forms.Label label8;
		private System.Windows.Forms.ListBox lstAssembly;
		private int iNumGames;

		public ExchangeAgentDisplayDialog(ExchangeAgent agent, int iNumGames)	{
			InitializeComponent();
			this.agent =agent;
			this.iNumGames = iNumGames;
		}

		#endregion

		#region Event handlers

		private void ExchangeAgentDisplay_Load(object sender, System.EventArgs e) {
			// This function sets all fields to their appropriate values.
			txtName.Text = agent.strName;
			if (agent is ExchangeAgent_Console)
				txtType.Text = "Console";
			else if (agent is ExchangeAgent_Programmed)
				txtType.Text = "A.I.";
			else
				txtType.Text = "Unknown";
			txtPlayed.Text = agent.iGames.ToString();
			txtFitness.Text = agent.dFitness.ToString();
			txtRank.Text = ((float) agent.dRank / (float) iNumGames).ToString();
			txtValue.Text = ((long) agent.lValue / iNumGames).ToString();
			// display program
			if (agent is ExchangeAgent_Programmed) {
				lstProgram.BeginUpdate();
				ArrayList list = ((ExchangeAgent_Programmed) agent).DisassembleProgram();
				foreach (string s in list)
					lstProgram.Items.Add(s);
				lstProgram.EndUpdate();
				lstProgram.Refresh();
				if (((ExchangeAgent_Programmed) agent).strAssembly.Length > 0) {
					lstAssembly.BeginUpdate();
					foreach (string s in ((ExchangeAgent_Programmed) agent).strAssembly.Split(new char[] { '\n' }))
						lstAssembly.Items.Add(s.Trim());
					lstAssembly.EndUpdate();
					lstAssembly.Refresh();
				}
			}
		}

		private void btnOK_Click(object sender, System.EventArgs e) {
			Close();
		}

		#endregion

		#region Uninteresting Windows Form Designer generated code
		protected override void Dispose(bool disposing)		{
			if (disposing) {
				if (components != null) {
				components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

	private void InitializeComponent()	{
		System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(ExchangeAgentDisplayDialog));
		this.label1 = new System.Windows.Forms.Label();
		this.label2 = new System.Windows.Forms.Label();
		this.label3 = new System.Windows.Forms.Label();
		this.label4 = new System.Windows.Forms.Label();
		this.lstProgram = new System.Windows.Forms.ListBox();
		this.btnOK = new System.Windows.Forms.Button();
		this.label6 = new System.Windows.Forms.Label();
		this.txtName = new System.Windows.Forms.TextBox();
		this.txtType = new System.Windows.Forms.TextBox();
		this.txtPlayed = new System.Windows.Forms.TextBox();
		this.txtFitness = new System.Windows.Forms.TextBox();
		this.label5 = new System.Windows.Forms.Label();
		this.lstAssembly = new System.Windows.Forms.ListBox();
		this.txtRank = new System.Windows.Forms.TextBox();
		this.label7 = new System.Windows.Forms.Label();
		this.txtValue = new System.Windows.Forms.TextBox();
		this.label8 = new System.Windows.Forms.Label();
		this.SuspendLayout();
		// 
		// label1
		// 
		this.label1.Location = new System.Drawing.Point(8, 8);
		this.label1.Name = "label1";
		this.label1.Size = new System.Drawing.Size(48, 23);
		this.label1.TabIndex = 0;
		this.label1.Text = "Name";
		this.label1.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
		// 
		// label2
		// 
		this.label2.Location = new System.Drawing.Point(8, 40);
		this.label2.Name = "label2";
		this.label2.Size = new System.Drawing.Size(48, 23);
		this.label2.TabIndex = 1;
		this.label2.Text = "Type";
		this.label2.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
		// 
		// label3
		// 
		this.label3.Anchor = System.Windows.Forms.AnchorStyles.Top;
		this.label3.Location = new System.Drawing.Point(8, 72);
		this.label3.Name = "label3";
		this.label3.Size = new System.Drawing.Size(48, 23);
		this.label3.TabIndex = 2;
		this.label3.Text = "Played";
		this.label3.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
		// 
		// label4
		// 
		this.label4.Anchor = System.Windows.Forms.AnchorStyles.Top;
		this.label4.Location = new System.Drawing.Point(240, 8);
		this.label4.Name = "label4";
		this.label4.Size = new System.Drawing.Size(48, 23);
		this.label4.TabIndex = 3;
		this.label4.Text = "Fitness";
		this.label4.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
		// 
		// lstProgram
		// 
		this.lstProgram.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
			| System.Windows.Forms.AnchorStyles.Left)));
		this.lstProgram.Location = new System.Drawing.Point(8, 128);
		this.lstProgram.Name = "lstProgram";
		this.lstProgram.Size = new System.Drawing.Size(224, 160);
		this.lstProgram.TabIndex = 5;
		// 
		// btnOK
		// 
		this.btnOK.Anchor = System.Windows.Forms.AnchorStyles.Bottom;
		this.btnOK.Location = new System.Drawing.Point(199, 296);
		this.btnOK.Name = "btnOK";
		this.btnOK.TabIndex = 0;
		this.btnOK.Text = "OK";
		this.btnOK.Click += new System.EventHandler(this.btnOK_Click);
		// 
		// label6
		// 
		this.label6.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
		this.label6.Location = new System.Drawing.Point(8, 104);
		this.label6.Name = "label6";
		this.label6.Size = new System.Drawing.Size(224, 23);
		this.label6.TabIndex = 7;
		this.label6.Text = "Program List";
		this.label6.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
		// 
		// txtName
		// 
		this.txtName.Location = new System.Drawing.Point(64, 8);
		this.txtName.Name = "txtName";
		this.txtName.ReadOnly = true;
		this.txtName.Size = new System.Drawing.Size(160, 20);
		this.txtName.TabIndex = 8;
		this.txtName.Text = "";
		// 
		// txtType
		// 
		this.txtType.Location = new System.Drawing.Point(64, 40);
		this.txtType.Name = "txtType";
		this.txtType.ReadOnly = true;
		this.txtType.Size = new System.Drawing.Size(160, 20);
		this.txtType.TabIndex = 9;
		this.txtType.Text = "";
		// 
		// txtPlayed
		// 
		this.txtPlayed.Anchor = System.Windows.Forms.AnchorStyles.Top;
		this.txtPlayed.Location = new System.Drawing.Point(64, 72);
		this.txtPlayed.Name = "txtPlayed";
		this.txtPlayed.ReadOnly = true;
		this.txtPlayed.Size = new System.Drawing.Size(160, 20);
		this.txtPlayed.TabIndex = 10;
		this.txtPlayed.Text = "";
		// 
		// txtFitness
		// 
		this.txtFitness.Anchor = System.Windows.Forms.AnchorStyles.Top;
		this.txtFitness.Location = new System.Drawing.Point(296, 8);
		this.txtFitness.Name = "txtFitness";
		this.txtFitness.ReadOnly = true;
		this.txtFitness.Size = new System.Drawing.Size(168, 20);
		this.txtFitness.TabIndex = 11;
		this.txtFitness.Text = "";
		// 
		// label5
		// 
		this.label5.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
		this.label5.Location = new System.Drawing.Point(240, 104);
		this.label5.Name = "label5";
		this.label5.Size = new System.Drawing.Size(224, 23);
		this.label5.TabIndex = 13;
		this.label5.Text = "Assembly";
		this.label5.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
		// 
		// lstAssembly
		// 
		this.lstAssembly.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
			| System.Windows.Forms.AnchorStyles.Left) 
			| System.Windows.Forms.AnchorStyles.Right)));
		this.lstAssembly.Location = new System.Drawing.Point(240, 128);
		this.lstAssembly.Name = "lstAssembly";
		this.lstAssembly.Size = new System.Drawing.Size(224, 160);
		this.lstAssembly.TabIndex = 14;
		// 
		// txtRank
		// 
		this.txtRank.Anchor = System.Windows.Forms.AnchorStyles.Top;
		this.txtRank.Location = new System.Drawing.Point(296, 40);
		this.txtRank.Name = "txtRank";
		this.txtRank.ReadOnly = true;
		this.txtRank.Size = new System.Drawing.Size(168, 20);
		this.txtRank.TabIndex = 16;
		this.txtRank.Text = "";
		// 
		// label7
		// 
		this.label7.Anchor = System.Windows.Forms.AnchorStyles.Top;
		this.label7.Location = new System.Drawing.Point(240, 40);
		this.label7.Name = "label7";
		this.label7.Size = new System.Drawing.Size(48, 23);
		this.label7.TabIndex = 15;
		this.label7.Text = "Rank";
		this.label7.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
		// 
		// txtValue
		// 
		this.txtValue.Anchor = System.Windows.Forms.AnchorStyles.Top;
		this.txtValue.Location = new System.Drawing.Point(296, 72);
		this.txtValue.Name = "txtValue";
		this.txtValue.ReadOnly = true;
		this.txtValue.Size = new System.Drawing.Size(168, 20);
		this.txtValue.TabIndex = 18;
		this.txtValue.Text = "";
		// 
		// label8
		// 
		this.label8.Anchor = System.Windows.Forms.AnchorStyles.Top;
		this.label8.Location = new System.Drawing.Point(240, 72);
		this.label8.Name = "label8";
		this.label8.Size = new System.Drawing.Size(48, 23);
		this.label8.TabIndex = 17;
		this.label8.Text = "Value";
		this.label8.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
		// 
		// ExchangeAgentDisplayDialog
		// 
		this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
		this.ClientSize = new System.Drawing.Size(472, 326);
		this.Controls.Add(this.txtValue);
		this.Controls.Add(this.label8);
		this.Controls.Add(this.txtRank);
		this.Controls.Add(this.label7);
		this.Controls.Add(this.lstAssembly);
		this.Controls.Add(this.label5);
		this.Controls.Add(this.txtFitness);
		this.Controls.Add(this.txtPlayed);
		this.Controls.Add(this.txtType);
		this.Controls.Add(this.txtName);
		this.Controls.Add(this.label6);
		this.Controls.Add(this.btnOK);
		this.Controls.Add(this.lstProgram);
		this.Controls.Add(this.label4);
		this.Controls.Add(this.label3);
		this.Controls.Add(this.label2);
		this.Controls.Add(this.label1);
		this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
		this.MaximizeBox = false;
		this.MinimizeBox = false;
		this.Name = "ExchangeAgentDisplayDialog";
		this.Text = "Agent";
		this.Load += new System.EventHandler(this.ExchangeAgentDisplay_Load);
		this.ResumeLayout(false);

	}
		#endregion

	}
}
