// The Exchange: Genetically Evolving Market Agents 
// Written by David J. Stein, Esq., 11/22/2004. See "License.html" for terms and conditions of use.
//
// This module contains the code for the form used to start a new Exchange game.

#region Using declarations

using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

#endregion

namespace The_Exchange_Namespace {

	public class ExchangeNewGameDialog : System.Windows.Forms.Form	{
		// This class represents the New Game dialog.

		#region Variables and initialization code

		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.ListBox lstAgents;
		private System.ComponentModel.Container components = null;
		private System.Windows.Forms.Button btnPlay;
		private System.Windows.Forms.Button btnLoad;
		private System.Windows.Forms.Button btnAdd;
		private System.Windows.Forms.Button btnRemove;
		private System.Windows.Forms.TextBox txtName;
		public ArrayList agents;
		private System.Windows.Forms.Button btnCancel;
		public string consolename = "Console Player";

		public ExchangeNewGameDialog()	{
			InitializeComponent();
			agents = new ArrayList();
		}

		#endregion

		#region User interface event handlers

		private void txtName_TextChanged(object sender, System.EventArgs e) {
			// This function sets the name of the player.
			consolename = txtName.Text;
		}

		private void btnLoad_Click(object sender, System.EventArgs e) {
			// This function loads an Exchange agent.
			OpenFileDialog open = new OpenFileDialog();
			open.Filter = "Exchange Agents (*.exa)|*.exa";
			if (open.ShowDialog() == DialogResult.OK) {  // selected an XML file
				ExchangeAgent agent = ExchangeAgent_Programmed.Load(open.FileName);
				if (agent != null) {
					agents.Add(agent);
					UpdateAgentList();
				}
			}
		}
		
		private void btnAdd_Click(object sender, System.EventArgs e) {
			// This function adds a new, random Exchange agent.
			agents.Add(new ExchangeAgent_Programmed(new Random((int) System.DateTime.Now.Ticks)));
			UpdateAgentList();
		}

		private void btnRemove_Click(object sender, System.EventArgs e) {
			// This function removes the selected Exchange agent.
			if (lstAgents.SelectedItems.Count == 1) {
				agents.RemoveAt(lstAgents.SelectedIndices[0]);
				UpdateAgentList();
			}
		}

		private void btnPlay_Click(object sender, System.EventArgs e) {
			// This button starts the game and closes the New Game dialog.
			DialogResult = DialogResult.OK;
			Close();
		}

		private void btnCancel_Click(object sender, System.EventArgs e) {
			// This button cancels the New Game dialog.
			DialogResult = DialogResult.Cancel;
			Close();
		}
		
		#endregion
		
		#region Helper functions

		private void UpdateAgentList() {
			// This function updates the Agents list.
			lstAgents.BeginUpdate();
			lstAgents.Items.Clear();
			foreach (ExchangeAgent agent in agents)
				lstAgents.Items.Add(agent.strName);
			lstAgents.EndUpdate();
			lstAgents.Refresh();
		}

		#endregion

		#region Uninteresting Windows Form Designer generated code

		protected override void Dispose(bool disposing)		{
			if (disposing) {
				if (components != null) {
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		private void InitializeComponent()	{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(ExchangeNewGameDialog));
			this.label1 = new System.Windows.Forms.Label();
			this.txtName = new System.Windows.Forms.TextBox();
			this.label2 = new System.Windows.Forms.Label();
			this.lstAgents = new System.Windows.Forms.ListBox();
			this.btnPlay = new System.Windows.Forms.Button();
			this.btnLoad = new System.Windows.Forms.Button();
			this.btnAdd = new System.Windows.Forms.Button();
			this.btnRemove = new System.Windows.Forms.Button();
			this.btnCancel = new System.Windows.Forms.Button();
			this.SuspendLayout();
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(65, 16);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(80, 23);
			this.label1.TabIndex = 0;
			this.label1.Text = "Your Name";
			this.label1.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// txtName
			// 
			this.txtName.Location = new System.Drawing.Point(49, 40);
			this.txtName.Name = "txtName";
			this.txtName.Size = new System.Drawing.Size(104, 20);
			this.txtName.TabIndex = 0;
			this.txtName.Text = "Console Player";
			this.txtName.TextAlign = System.Windows.Forms.HorizontalAlignment.Center;
			this.txtName.TextChanged += new System.EventHandler(this.txtName_TextChanged);
			// 
			// label2
			// 
			this.label2.Location = new System.Drawing.Point(72, 80);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(72, 23);
			this.label2.TabIndex = 2;
			this.label2.Text = "Opponents";
			this.label2.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// lstAgents
			// 
			this.lstAgents.Location = new System.Drawing.Point(8, 112);
			this.lstAgents.Name = "lstAgents";
			this.lstAgents.Size = new System.Drawing.Size(96, 95);
			this.lstAgents.TabIndex = 3;
			// 
			// btnPlay
			// 
			this.btnPlay.Location = new System.Drawing.Point(19, 224);
			this.btnPlay.Name = "btnPlay";
			this.btnPlay.TabIndex = 4;
			this.btnPlay.Text = "OK";
			this.btnPlay.Click += new System.EventHandler(this.btnPlay_Click);
			// 
			// btnLoad
			// 
			this.btnLoad.Location = new System.Drawing.Point(120, 112);
			this.btnLoad.Name = "btnLoad";
			this.btnLoad.Size = new System.Drawing.Size(72, 23);
			this.btnLoad.TabIndex = 1;
			this.btnLoad.Text = "Load";
			this.btnLoad.Click += new System.EventHandler(this.btnLoad_Click);
			// 
			// btnAdd
			// 
			this.btnAdd.Location = new System.Drawing.Point(120, 148);
			this.btnAdd.Name = "btnAdd";
			this.btnAdd.Size = new System.Drawing.Size(72, 23);
			this.btnAdd.TabIndex = 2;
			this.btnAdd.Text = "Create";
			this.btnAdd.Click += new System.EventHandler(this.btnAdd_Click);
			// 
			// btnRemove
			// 
			this.btnRemove.Location = new System.Drawing.Point(120, 184);
			this.btnRemove.Name = "btnRemove";
			this.btnRemove.Size = new System.Drawing.Size(72, 23);
			this.btnRemove.TabIndex = 3;
			this.btnRemove.Text = "Remove";
			this.btnRemove.Click += new System.EventHandler(this.btnRemove_Click);
			// 
			// btnCancel
			// 
			this.btnCancel.Location = new System.Drawing.Point(120, 224);
			this.btnCancel.Name = "btnCancel";
			this.btnCancel.Size = new System.Drawing.Size(72, 23);
			this.btnCancel.TabIndex = 5;
			this.btnCancel.Text = "Cancel";
			this.btnCancel.Click += new System.EventHandler(this.btnCancel_Click);
			// 
			// ExchangeNewGameDialog
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(202, 264);
			this.ControlBox = false;
			this.Controls.Add(this.btnCancel);
			this.Controls.Add(this.btnRemove);
			this.Controls.Add(this.btnAdd);
			this.Controls.Add(this.btnLoad);
			this.Controls.Add(this.btnPlay);
			this.Controls.Add(this.lstAgents);
			this.Controls.Add(this.label2);
			this.Controls.Add(this.txtName);
			this.Controls.Add(this.label1);
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedSingle;
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.Name = "ExchangeNewGameDialog";
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterParent;
			this.Text = "New Game";
			this.ResumeLayout(false);

		}
		#endregion

	}
}
