// The Exchange: Genetically Evolving Market Agents 
// Written by David J. Stein, Esq., 11/22/2004. See "License.html" for terms and conditions of use.
//
// This module contains the code for the Exchange simulation game.

#region Using declarations

using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

#endregion

namespace The_Exchange_Namespace {

	public class ExchangePlayerDialog : System.Windows.Forms.Form	{
		// This class represents the form for displaying player data.

		#region Variables and initialization code

		private ExchangeAgent agent;
		private ExchangeSimulation exchange;

		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.ColumnHeader columnHeader1;
		private System.Windows.Forms.ColumnHeader columnHeader2;
		private System.Windows.Forms.ColumnHeader columnHeader3;
		private System.Windows.Forms.ColumnHeader columnHeader4;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.Label label5;
		private System.Windows.Forms.Button btnOK;
		private System.Windows.Forms.TextBox txtValue;
		private System.Windows.Forms.Timer timerUpdate;
		private System.Windows.Forms.ListView lstHoldings;
		private System.Windows.Forms.TextBox txtName;
		private System.Windows.Forms.TextBox txtRank;
		private System.Windows.Forms.TextBox txtType;
		private System.Windows.Forms.TextBox txtCredits;
		private System.ComponentModel.IContainer components;

		public ExchangePlayerDialog(ExchangeAgent agent, ExchangeSimulation exchange)	{
			InitializeComponent();
			this.agent = agent;
			this.exchange = exchange;
		}

		#endregion

		#region Event handlers
		
		private void btnOK_Click(object sender, System.EventArgs e) {
			// This function handles clicks for the OK button.
			Close();
		}

		private void timerUpdate_Tick(object sender, System.EventArgs e) {
			// This function handles timer ticks.
			UpdateFields();
		}

		private void ExchangePlayerDialog_Load(object sender, System.EventArgs e) {
			// This function updates the form when it loads.
			UpdateFields();
		}

		private void UpdateFields() {
			// This function updates all fields.
			txtName.Text = agent.strName;
			txtRank.Text = agent.player.iRank.ToString();
			txtType.Text = (agent is ExchangeAgent_Console ? "Human" : agent is ExchangeAgent_Programmed ? "A.I." : "Unknown");
			txtCredits.Text = agent.player.iCredits.ToString();
			lstHoldings.BeginUpdate();
			lstHoldings.Items.Clear();
			for (int i = 0; i < exchange.goods.Count; i++)
				lstHoldings.Items.Add(new ListViewItem(new string[] { ((Good) exchange.goods[i]).strName, agent.player.iHoldings[i].ToString(), ((long) (agent.player.iHoldings[i] * ((Good) exchange.goods[i]).iPrice)).ToString(), agent.player.iProduction == i ? "*" : "" }));
			lstHoldings.EndUpdate();
			lstHoldings.Refresh();
			txtValue.Text = agent.player.lTotalValue.ToString();
		}

		#endregion

		#region Uninteresting Windows Form Designer generated code

		protected override void Dispose(bool disposing)		{
			if (disposing) {
				if (components != null) {
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		private void InitializeComponent()	{
			this.components = new System.ComponentModel.Container();
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(ExchangePlayerDialog));
			this.label1 = new System.Windows.Forms.Label();
			this.label2 = new System.Windows.Forms.Label();
			this.label3 = new System.Windows.Forms.Label();
			this.lstHoldings = new System.Windows.Forms.ListView();
			this.columnHeader1 = new System.Windows.Forms.ColumnHeader();
			this.columnHeader2 = new System.Windows.Forms.ColumnHeader();
			this.columnHeader3 = new System.Windows.Forms.ColumnHeader();
			this.columnHeader4 = new System.Windows.Forms.ColumnHeader();
			this.label4 = new System.Windows.Forms.Label();
			this.label5 = new System.Windows.Forms.Label();
			this.btnOK = new System.Windows.Forms.Button();
			this.txtValue = new System.Windows.Forms.TextBox();
			this.txtName = new System.Windows.Forms.TextBox();
			this.txtRank = new System.Windows.Forms.TextBox();
			this.txtType = new System.Windows.Forms.TextBox();
			this.txtCredits = new System.Windows.Forms.TextBox();
			this.timerUpdate = new System.Windows.Forms.Timer(this.components);
			this.SuspendLayout();
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(8, 8);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(56, 23);
			this.label1.TabIndex = 0;
			this.label1.Text = "Name";
			this.label1.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label2
			// 
			this.label2.Location = new System.Drawing.Point(8, 48);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(56, 23);
			this.label2.TabIndex = 1;
			this.label2.Text = "Type";
			this.label2.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label3
			// 
			this.label3.Location = new System.Drawing.Point(160, 48);
			this.label3.Name = "label3";
			this.label3.Size = new System.Drawing.Size(56, 23);
			this.label3.TabIndex = 2;
			this.label3.Text = "Credits";
			this.label3.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// lstHoldings
			// 
			this.lstHoldings.Columns.AddRange(new System.Windows.Forms.ColumnHeader[] {
																												  this.columnHeader1,
																												  this.columnHeader2,
																												  this.columnHeader3,
																												  this.columnHeader4});
			this.lstHoldings.Location = new System.Drawing.Point(8, 80);
			this.lstHoldings.Name = "lstHoldings";
			this.lstHoldings.Size = new System.Drawing.Size(304, 152);
			this.lstHoldings.TabIndex = 4;
			this.lstHoldings.View = System.Windows.Forms.View.Details;
			// 
			// columnHeader1
			// 
			this.columnHeader1.Text = "Good";
			this.columnHeader1.Width = 80;
			// 
			// columnHeader2
			// 
			this.columnHeader2.Text = "Holdings";
			this.columnHeader2.Width = 65;
			// 
			// columnHeader3
			// 
			this.columnHeader3.Text = "Total Value";
			this.columnHeader3.Width = 77;
			// 
			// columnHeader4
			// 
			this.columnHeader4.Text = "Producing?";
			this.columnHeader4.Width = 71;
			// 
			// label4
			// 
			this.label4.Location = new System.Drawing.Point(160, 8);
			this.label4.Name = "label4";
			this.label4.Size = new System.Drawing.Size(56, 23);
			this.label4.TabIndex = 5;
			this.label4.Text = "Rank";
			this.label4.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label5
			// 
			this.label5.Location = new System.Drawing.Point(74, 248);
			this.label5.Name = "label5";
			this.label5.Size = new System.Drawing.Size(64, 23);
			this.label5.TabIndex = 6;
			this.label5.Text = "Total Value";
			this.label5.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// btnOK
			// 
			this.btnOK.Location = new System.Drawing.Point(123, 280);
			this.btnOK.Name = "btnOK";
			this.btnOK.TabIndex = 7;
			this.btnOK.Text = "OK";
			this.btnOK.Click += new System.EventHandler(this.btnOK_Click);
			// 
			// txtValue
			// 
			this.txtValue.Location = new System.Drawing.Point(146, 248);
			this.txtValue.Name = "txtValue";
			this.txtValue.ReadOnly = true;
			this.txtValue.TabIndex = 8;
			this.txtValue.Text = "";
			// 
			// txtName
			// 
			this.txtName.Location = new System.Drawing.Point(56, 8);
			this.txtName.Name = "txtName";
			this.txtName.ReadOnly = true;
			this.txtName.TabIndex = 9;
			this.txtName.Text = "";
			// 
			// txtRank
			// 
			this.txtRank.Location = new System.Drawing.Point(208, 8);
			this.txtRank.Name = "txtRank";
			this.txtRank.ReadOnly = true;
			this.txtRank.TabIndex = 10;
			this.txtRank.Text = "";
			// 
			// txtType
			// 
			this.txtType.Location = new System.Drawing.Point(56, 48);
			this.txtType.Name = "txtType";
			this.txtType.ReadOnly = true;
			this.txtType.TabIndex = 11;
			this.txtType.Text = "";
			// 
			// txtCredits
			// 
			this.txtCredits.Location = new System.Drawing.Point(208, 48);
			this.txtCredits.Name = "txtCredits";
			this.txtCredits.ReadOnly = true;
			this.txtCredits.TabIndex = 12;
			this.txtCredits.Text = "";
			// 
			// timerUpdate
			// 
			this.timerUpdate.Enabled = true;
			this.timerUpdate.Interval = 1000;
			this.timerUpdate.Tick += new System.EventHandler(this.timerUpdate_Tick);
			// 
			// ExchangePlayerDialog
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(320, 310);
			this.ControlBox = false;
			this.Controls.Add(this.txtCredits);
			this.Controls.Add(this.txtType);
			this.Controls.Add(this.txtRank);
			this.Controls.Add(this.txtName);
			this.Controls.Add(this.txtValue);
			this.Controls.Add(this.btnOK);
			this.Controls.Add(this.label5);
			this.Controls.Add(this.label4);
			this.Controls.Add(this.lstHoldings);
			this.Controls.Add(this.label3);
			this.Controls.Add(this.label2);
			this.Controls.Add(this.label1);
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.Name = "ExchangePlayerDialog";
			this.Text = "Player";
			this.Load += new System.EventHandler(this.ExchangePlayerDialog_Load);
			this.ResumeLayout(false);

		}
		#endregion

	}
}
