// The Exchange: Genetically Evolving Market Agents 
// Written by David J. Stein, Esq., 11/22/2004. See "License.html" for terms and conditions of use.
//
// This module contains the code for the form used to start a new Exchange game.

#region Using declarations

using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

#endregion

namespace The_Exchange_Namespace {

	public class ExchangeStartupDialog : System.Windows.Forms.Form	{
		// This class represents the startup dialog (the initial screen.)

		#region Variables, initialization code, and Main

		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.Button btnArena;
		private System.Windows.Forms.Button btnDesigner;
		private System.Windows.Forms.Button btnPlay;
		private System.Windows.Forms.PictureBox pictureBox1;
		private System.Windows.Forms.PictureBox pictureBox2;
		private System.Windows.Forms.PictureBox pictureBox3;
		private System.Windows.Forms.PictureBox pictureBox4;
		private System.Windows.Forms.Button btnAbout;
		private System.ComponentModel.Container components = null;

		public ExchangeStartupDialog()	{
			InitializeComponent();
		}

		[STAThread]
		static void Main() {
			Application.Run(new ExchangeStartupDialog());
		}

		#endregion

		#region User interface event handlers

		private void btnPlay_Click(object sender, System.EventArgs e) {
			// This function starts the Exchange game.
			Hide();
			ExchangeGame g = new ExchangeGame();
			g.ShowDialog();
			Show();
			SetTopLevel(true);  // move to front
		}

		private void btnDesigner_Click(object sender, System.EventArgs e) {
			// This function starts the Exchange Agent Designer.
			Hide();
			ExchangeAgentDesigner d = new ExchangeAgentDesigner();
			d.ShowDialog();
			Show();
			SetTopLevel(true);  // move to front
		}

		private void btnArena_Click(object sender, System.EventArgs e) {
			// This function starts the Exchange Agent Arena.
			Hide();
			ExchangeAgentArena a = new ExchangeAgentArena();
			a.ShowDialog();
			Show();
			SetTopLevel(true);  // move to front
		}

		private void btnAbout_Click(object sender, System.EventArgs e) {
			// This function shows the About dialog box.
			ExchangeAboutDialog a = new ExchangeAboutDialog();
			a.ShowDialog();
		}

		#endregion
		
		#region Uninteresting Windows Form Designer generated code
		protected override void Dispose(bool disposing)		{
			if (disposing) {
				if (components != null) {
				components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

	private void InitializeComponent()	{
		System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(ExchangeStartupDialog));
		this.label1 = new System.Windows.Forms.Label();
		this.label2 = new System.Windows.Forms.Label();
		this.groupBox1 = new System.Windows.Forms.GroupBox();
		this.btnAbout = new System.Windows.Forms.Button();
		this.pictureBox4 = new System.Windows.Forms.PictureBox();
		this.pictureBox3 = new System.Windows.Forms.PictureBox();
		this.pictureBox2 = new System.Windows.Forms.PictureBox();
		this.pictureBox1 = new System.Windows.Forms.PictureBox();
		this.btnArena = new System.Windows.Forms.Button();
		this.btnDesigner = new System.Windows.Forms.Button();
		this.btnPlay = new System.Windows.Forms.Button();
		this.groupBox1.SuspendLayout();
		this.SuspendLayout();
		// 
		// label1
		// 
		this.label1.BackColor = System.Drawing.Color.Transparent;
		this.label1.Font = new System.Drawing.Font("Courier New", 14.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
		this.label1.ForeColor = System.Drawing.Color.WhiteSmoke;
		this.label1.Location = new System.Drawing.Point(8, 40);
		this.label1.Name = "label1";
		this.label1.Size = new System.Drawing.Size(256, 24);
		this.label1.TabIndex = 0;
		this.label1.Text = "The Exchange";
		this.label1.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
		// 
		// label2
		// 
		this.label2.BackColor = System.Drawing.Color.Transparent;
		this.label2.Font = new System.Drawing.Font("Courier New", 14.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
		this.label2.ForeColor = System.Drawing.Color.WhiteSmoke;
		this.label2.Location = new System.Drawing.Point(8, 88);
		this.label2.Name = "label2";
		this.label2.Size = new System.Drawing.Size(256, 24);
		this.label2.TabIndex = 1;
		this.label2.Text = "A Market Simulation";
		this.label2.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
		// 
		// groupBox1
		// 
		this.groupBox1.BackColor = System.Drawing.Color.DarkBlue;
		this.groupBox1.Controls.Add(this.btnAbout);
		this.groupBox1.Controls.Add(this.pictureBox4);
		this.groupBox1.Controls.Add(this.pictureBox3);
		this.groupBox1.Controls.Add(this.pictureBox2);
		this.groupBox1.Controls.Add(this.pictureBox1);
		this.groupBox1.Controls.Add(this.btnArena);
		this.groupBox1.Controls.Add(this.btnDesigner);
		this.groupBox1.Controls.Add(this.btnPlay);
		this.groupBox1.Controls.Add(this.label2);
		this.groupBox1.Controls.Add(this.label1);
		this.groupBox1.Location = new System.Drawing.Point(8, 8);
		this.groupBox1.Name = "groupBox1";
		this.groupBox1.Size = new System.Drawing.Size(272, 272);
		this.groupBox1.TabIndex = 2;
		this.groupBox1.TabStop = false;
		// 
		// btnAbout
		// 
		this.btnAbout.BackColor = System.Drawing.Color.DarkGray;
		this.btnAbout.Font = new System.Drawing.Font("Courier New", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
		this.btnAbout.ForeColor = System.Drawing.Color.WhiteSmoke;
		this.btnAbout.Location = new System.Drawing.Point(80, 240);
		this.btnAbout.Name = "btnAbout";
		this.btnAbout.Size = new System.Drawing.Size(120, 23);
		this.btnAbout.TabIndex = 9;
		this.btnAbout.Text = "About";
		this.btnAbout.Click += new System.EventHandler(this.btnAbout_Click);
		// 
		// pictureBox4
		// 
		this.pictureBox4.Image = ((System.Drawing.Image)(resources.GetObject("pictureBox4.Image")));
		this.pictureBox4.Location = new System.Drawing.Point(8, 250);
		this.pictureBox4.Name = "pictureBox4";
		this.pictureBox4.Size = new System.Drawing.Size(16, 16);
		this.pictureBox4.TabIndex = 8;
		this.pictureBox4.TabStop = false;
		// 
		// pictureBox3
		// 
		this.pictureBox3.Image = ((System.Drawing.Image)(resources.GetObject("pictureBox3.Image")));
		this.pictureBox3.Location = new System.Drawing.Point(250, 250);
		this.pictureBox3.Name = "pictureBox3";
		this.pictureBox3.Size = new System.Drawing.Size(16, 16);
		this.pictureBox3.TabIndex = 7;
		this.pictureBox3.TabStop = false;
		// 
		// pictureBox2
		// 
		this.pictureBox2.Image = ((System.Drawing.Image)(resources.GetObject("pictureBox2.Image")));
		this.pictureBox2.Location = new System.Drawing.Point(250, 12);
		this.pictureBox2.Name = "pictureBox2";
		this.pictureBox2.Size = new System.Drawing.Size(16, 16);
		this.pictureBox2.TabIndex = 6;
		this.pictureBox2.TabStop = false;
		// 
		// pictureBox1
		// 
		this.pictureBox1.Image = ((System.Drawing.Image)(resources.GetObject("pictureBox1.Image")));
		this.pictureBox1.Location = new System.Drawing.Point(8, 12);
		this.pictureBox1.Name = "pictureBox1";
		this.pictureBox1.Size = new System.Drawing.Size(16, 16);
		this.pictureBox1.TabIndex = 5;
		this.pictureBox1.TabStop = false;
		// 
		// btnArena
		// 
		this.btnArena.BackColor = System.Drawing.Color.DarkGray;
		this.btnArena.Font = new System.Drawing.Font("Courier New", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
		this.btnArena.ForeColor = System.Drawing.Color.WhiteSmoke;
		this.btnArena.Location = new System.Drawing.Point(80, 208);
		this.btnArena.Name = "btnArena";
		this.btnArena.Size = new System.Drawing.Size(120, 23);
		this.btnArena.TabIndex = 2;
		this.btnArena.Text = "Agent Arena";
		this.btnArena.Click += new System.EventHandler(this.btnArena_Click);
		// 
		// btnDesigner
		// 
		this.btnDesigner.BackColor = System.Drawing.Color.DarkGray;
		this.btnDesigner.Font = new System.Drawing.Font("Courier New", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
		this.btnDesigner.ForeColor = System.Drawing.Color.WhiteSmoke;
		this.btnDesigner.Location = new System.Drawing.Point(80, 176);
		this.btnDesigner.Name = "btnDesigner";
		this.btnDesigner.Size = new System.Drawing.Size(120, 23);
		this.btnDesigner.TabIndex = 1;
		this.btnDesigner.Text = "Agent Designer";
		this.btnDesigner.Click += new System.EventHandler(this.btnDesigner_Click);
		// 
		// btnPlay
		// 
		this.btnPlay.BackColor = System.Drawing.Color.DarkGray;
		this.btnPlay.Font = new System.Drawing.Font("Courier New", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
		this.btnPlay.ForeColor = System.Drawing.Color.WhiteSmoke;
		this.btnPlay.Location = new System.Drawing.Point(80, 144);
		this.btnPlay.Name = "btnPlay";
		this.btnPlay.Size = new System.Drawing.Size(120, 23);
		this.btnPlay.TabIndex = 0;
		this.btnPlay.Text = "Play Simulation";
		this.btnPlay.Click += new System.EventHandler(this.btnPlay_Click);
		// 
		// ExchangeStartupDialog
		// 
		this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
		this.BackColor = System.Drawing.Color.DarkBlue;
		this.ClientSize = new System.Drawing.Size(290, 288);
		this.Controls.Add(this.groupBox1);
		this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedToolWindow;
		this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
		this.MaximizeBox = false;
		this.MinimizeBox = false;
		this.Name = "ExchangeStartupDialog";
		this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
		this.Text = "The Exchange";
		this.groupBox1.ResumeLayout(false);
		this.ResumeLayout(false);

	}
		#endregion

	}
}
